/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 64

#include "nimbase.h"
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
typedef struct TNimTypeV2 TNimTypeV2;
typedef struct tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g;
typedef struct RootObj RootObj;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content;
typedef struct tyObject_HSlice__O4ak9be9cxLOjU6hb2Qjt9bhA tyObject_HSlice__O4ak9be9cxLOjU6hb2Qjt9bhA;
typedef NU8 tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA;
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
typedef NimStringV2 tyArray__wVkbv9aOuop9cKsgoz0aezKQ[10];
struct TNimTypeV2 {
	void* destructor;
	NI size;
	NI16 align;
	NI16 depth;
	NU32* display;
	void* traceImpl;
	void* typeInfoV1;
	NI flags;
	void* vTable[SEQ_DECL_SIZE];
};
struct RootObj {
	TNimTypeV2* m_type;
};
typedef NU8 tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA;
struct tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g {
	RootObj Sup;
	tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA kind;
	NI start;
	NI length;
	NCSTRING buf;
	NI pos;
	tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA state;
	tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA lang;
};
typedef NimStringV2 tyArray__W7G5m750XsEydrrdcBFnuA[66];
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  NI len; tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content* p;
};
typedef NU8 tySet_tyEnum_TokenizerFlag__3fe5tVd800nlQ3htR4f9cXw;
typedef NU8 tyEnum_TokenizerFlag__3fe5tVd800nlQ3htR4f9cXw;
typedef NimStringV2 tyArray__cLKWlXEmBJfDEe4kfvzxkw[48];
typedef NimStringV2 tyArray__NwaMkOW9b1iUX9bIMAHgGTww[77];
typedef NimStringV2 tyArray__7aIKux9btsNssxB8Y2FsvcA[37];
typedef NimStringV2 tyArray__n9aEI9bb6tgFT8eY9a5zR4szA[53];
struct tyObject_HSlice__O4ak9be9cxLOjU6hb2Qjt9bhA {
	NIM_CHAR a;
	NIM_CHAR b;
};
typedef NimStringV2 tyArray__mlDDS9c5sg9beP8qh9bHeHuiQ[35];
typedef NimStringV2 tyArray__9amQAAkHuxu9cNghyKvw0urQ[37];
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content { NI cap; NimStringV2 data[SEQ_DECL_SIZE]; };
N_LIB_PRIVATE N_NIMCALL(NI, nsuCmpIgnoreStyle)(NimStringV2 a_p0, NimStringV2 b_p1);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
N_LIB_PRIVATE N_NIMCALL(void, initGeneralTokenizer__packagesZdocutilsZhighlite_u120)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0, NCSTRING buf_p1);
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(void, nimNextToken__packagesZdocutilsZhighlite_u404)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0, NimStringV2* keywords_p1, NI keywords_p1Len_0);
static N_INLINE(void, nimAddCharV1)(NimStringV2* s_p0, NIM_CHAR c_p1);
N_LIB_PRIVATE N_NIMCALL(void, prepareAdd)(NimStringV2* s_p0, NI addLen_p1);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA, nimGetKeyword__packagesZdocutilsZhighlite_u159)(NimStringV2 id_p0);
N_LIB_PRIVATE N_NIMCALL(NI, isKeyword__packagesZdocutilsZhighlite_u358)(NimStringV2* x_p0, NI x_p0Len_0, NimStringV2 y_p1);
N_LIB_PRIVATE N_NIMCALL(NI, binarySearch__packagesZdocutilsZhighlite_u362)(NimStringV2* a_p0, NI a_p0Len_0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u2691)(NimStringV2 dest_p0);
N_LIB_PRIVATE N_NIMCALL(NI, nimNumberPostfix__packagesZdocutilsZhighlite_u245)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0, NI position_p1);
N_LIB_PRIVATE N_NIMCALL(NI, nimNumber__packagesZdocutilsZhighlite_u301)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0, NI position_p1);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqPayload)(NI cap_p0, NI elemSize_p1, NI elemAlign_p2);
N_LIB_PRIVATE N_NIMCALL(void, cppNextToken__packagesZdocutilsZhighlite_u1227)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0);
N_LIB_PRIVATE N_NIMCALL(void, clikeNextToken__packagesZdocutilsZhighlite_u875)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0, NimStringV2* keywords_p1, NI keywords_p1Len_0, tySet_tyEnum_TokenizerFlag__3fe5tVd800nlQ3htR4f9cXw flags_p2);
N_LIB_PRIVATE N_NIMCALL(NI, generalNumber__packagesZdocutilsZhighlite_u747)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0, NI position_p1);
N_LIB_PRIVATE N_NIMCALL(NI, generalStrLit__packagesZdocutilsZhighlite_u803)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0, NI position_p1);
N_LIB_PRIVATE N_NIMCALL(void, csharpNextToken__packagesZdocutilsZhighlite_u1267)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0);
N_LIB_PRIVATE N_NIMCALL(void, cNextToken__packagesZdocutilsZhighlite_u1187)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0);
N_LIB_PRIVATE N_NIMCALL(void, javaNextToken__packagesZdocutilsZhighlite_u1307)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0);
N_LIB_PRIVATE N_NIMCALL(void, yamlNextToken__packagesZdocutilsZhighlite_u1485)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0);
N_LIB_PRIVATE N_NIMCALL(void, yamlPossibleNumber__packagesZdocutilsZhighlite_u1363)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0, NI* pos_p1);
static N_INLINE(NIM_BOOL, contains__int128_u922)(tyObject_HSlice__O4ak9be9cxLOjU6hb2Qjt9bhA s_p0, NIM_CHAR value_p1);
static N_INLINE(tyObject_HSlice__O4ak9be9cxLOjU6hb2Qjt9bhA, dotdot___int128_u871)(NIM_CHAR a_p0, NIM_CHAR b_p1);
N_LIB_PRIVATE N_NIMCALL(void, yamlPlainStrLit__packagesZdocutilsZhighlite_u1347)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0, NI* pos_p1);
N_LIB_PRIVATE N_NIMCALL(void, pythonNextToken__packagesZdocutilsZhighlite_u1980)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0);
N_LIB_PRIVATE N_NIMCALL(void, cmdNextToken__packagesZdocutilsZhighlite_u2020)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0, NIM_BOOL dollarPrompt_p1);
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_2 = { 4 | NIM_STRLIT_FLAG, "none" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_3 = { 3 | NIM_STRLIT_FLAG, "Nim" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_4 = { 3 | NIM_STRLIT_FLAG, "C++" };
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_5 = { 2 | NIM_STRLIT_FLAG, "C#" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_6 = { 1 | NIM_STRLIT_FLAG, "C" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_7 = { 4 | NIM_STRLIT_FLAG, "Java" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_8 = { 4 | NIM_STRLIT_FLAG, "Yaml" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_9 = { 6 | NIM_STRLIT_FLAG, "Python" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_10 = { 3 | NIM_STRLIT_FLAG, "Cmd" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_11 = { 7 | NIM_STRLIT_FLAG, "Console" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_12 = { 3 | NIM_STRLIT_FLAG, "cpp" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_13 = { 6 | NIM_STRLIT_FLAG, "csharp" };
N_LIB_PRIVATE TNimTypeV2 NTIv2__t8mWIshWZpNBbL0h6CSV0g_;
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_15 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__0kVEnxqJYMmsZjjZ9a1FeBw_16 = {0, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_15};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_17 = { 4 | NIM_STRLIT_FLAG, "addr" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_18 = { 3 | NIM_STRLIT_FLAG, "and" };
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_19 = { 2 | NIM_STRLIT_FLAG, "as" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_20 = { 3 | NIM_STRLIT_FLAG, "asm" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_21 = { 4 | NIM_STRLIT_FLAG, "bind" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_22 = { 5 | NIM_STRLIT_FLAG, "block" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_23 = { 5 | NIM_STRLIT_FLAG, "break" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_24 = { 4 | NIM_STRLIT_FLAG, "case" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_25 = { 4 | NIM_STRLIT_FLAG, "cast" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_26 = { 7 | NIM_STRLIT_FLAG, "concept" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_27 = { 5 | NIM_STRLIT_FLAG, "const" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_28 = { 8 | NIM_STRLIT_FLAG, "continue" };
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_29 = { 9 | NIM_STRLIT_FLAG, "converter" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_30 = { 5 | NIM_STRLIT_FLAG, "defer" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_31 = { 7 | NIM_STRLIT_FLAG, "discard" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_32 = { 8 | NIM_STRLIT_FLAG, "distinct" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_33 = { 3 | NIM_STRLIT_FLAG, "div" };
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_34 = { 2 | NIM_STRLIT_FLAG, "do" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_35 = { 4 | NIM_STRLIT_FLAG, "elif" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_36 = { 4 | NIM_STRLIT_FLAG, "else" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_37 = { 3 | NIM_STRLIT_FLAG, "end" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_38 = { 4 | NIM_STRLIT_FLAG, "enum" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_39 = { 6 | NIM_STRLIT_FLAG, "except" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_40 = { 6 | NIM_STRLIT_FLAG, "export" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_41 = { 7 | NIM_STRLIT_FLAG, "finally" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_42 = { 3 | NIM_STRLIT_FLAG, "for" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_43 = { 4 | NIM_STRLIT_FLAG, "from" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_44 = { 4 | NIM_STRLIT_FLAG, "func" };
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_45 = { 2 | NIM_STRLIT_FLAG, "if" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_46 = { 6 | NIM_STRLIT_FLAG, "import" };
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_47 = { 2 | NIM_STRLIT_FLAG, "in" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_48 = { 7 | NIM_STRLIT_FLAG, "include" };
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_49 = { 9 | NIM_STRLIT_FLAG, "interface" };
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_50 = { 2 | NIM_STRLIT_FLAG, "is" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_51 = { 5 | NIM_STRLIT_FLAG, "isnot" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_52 = { 8 | NIM_STRLIT_FLAG, "iterator" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_53 = { 3 | NIM_STRLIT_FLAG, "let" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_54 = { 5 | NIM_STRLIT_FLAG, "macro" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_55 = { 6 | NIM_STRLIT_FLAG, "method" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_56 = { 5 | NIM_STRLIT_FLAG, "mixin" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_57 = { 3 | NIM_STRLIT_FLAG, "mod" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_58 = { 3 | NIM_STRLIT_FLAG, "nil" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_59 = { 3 | NIM_STRLIT_FLAG, "not" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_60 = { 5 | NIM_STRLIT_FLAG, "notin" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_61 = { 6 | NIM_STRLIT_FLAG, "object" };
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_62 = { 2 | NIM_STRLIT_FLAG, "of" };
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_63 = { 2 | NIM_STRLIT_FLAG, "or" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_64 = { 3 | NIM_STRLIT_FLAG, "out" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_65 = { 4 | NIM_STRLIT_FLAG, "proc" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_66 = { 3 | NIM_STRLIT_FLAG, "ptr" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_67 = { 5 | NIM_STRLIT_FLAG, "raise" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_68 = { 3 | NIM_STRLIT_FLAG, "ref" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_69 = { 6 | NIM_STRLIT_FLAG, "return" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_70 = { 3 | NIM_STRLIT_FLAG, "shl" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_71 = { 3 | NIM_STRLIT_FLAG, "shr" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_72 = { 6 | NIM_STRLIT_FLAG, "static" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_73 = { 8 | NIM_STRLIT_FLAG, "template" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_74 = { 3 | NIM_STRLIT_FLAG, "try" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_75 = { 5 | NIM_STRLIT_FLAG, "tuple" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_76 = { 4 | NIM_STRLIT_FLAG, "type" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_77 = { 5 | NIM_STRLIT_FLAG, "using" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_78 = { 3 | NIM_STRLIT_FLAG, "var" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_79 = { 4 | NIM_STRLIT_FLAG, "when" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_80 = { 5 | NIM_STRLIT_FLAG, "while" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_81 = { 3 | NIM_STRLIT_FLAG, "xor" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_82 = { 5 | NIM_STRLIT_FLAG, "yield" };
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__0kVEnxqJYMmsZjjZ9a1FeBw_83 = {
0x00, 0x00, 0x00, 0x00, 0x72, 0xec, 0x00, 0xf4,
0x01, 0x00, 0x00, 0x50, 0x00, 0x00, 0x00, 0x50,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
static const NimStringV2 TM__0kVEnxqJYMmsZjjZ9a1FeBw_84 = {0, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_15};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_85 = { 4 | NIM_STRLIT_FLAG, "auto" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_86 = { 5 | NIM_STRLIT_FLAG, "catch" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_87 = { 4 | NIM_STRLIT_FLAG, "char" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_88 = { 5 | NIM_STRLIT_FLAG, "class" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_89 = { 7 | NIM_STRLIT_FLAG, "default" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_90 = { 6 | NIM_STRLIT_FLAG, "delete" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_91 = { 6 | NIM_STRLIT_FLAG, "double" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_92 = { 6 | NIM_STRLIT_FLAG, "extern" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_93 = { 5 | NIM_STRLIT_FLAG, "float" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_94 = { 6 | NIM_STRLIT_FLAG, "friend" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_95 = { 4 | NIM_STRLIT_FLAG, "goto" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_96 = { 6 | NIM_STRLIT_FLAG, "inline" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_97 = { 3 | NIM_STRLIT_FLAG, "int" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_98 = { 4 | NIM_STRLIT_FLAG, "long" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_99 = { 3 | NIM_STRLIT_FLAG, "new" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_100 = { 8 | NIM_STRLIT_FLAG, "operator" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_101 = { 7 | NIM_STRLIT_FLAG, "private" };
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_102 = { 9 | NIM_STRLIT_FLAG, "protected" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_103 = { 6 | NIM_STRLIT_FLAG, "public" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_104 = { 8 | NIM_STRLIT_FLAG, "register" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_105 = { 5 | NIM_STRLIT_FLAG, "short" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_106 = { 6 | NIM_STRLIT_FLAG, "signed" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_107 = { 6 | NIM_STRLIT_FLAG, "sizeof" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_108 = { 6 | NIM_STRLIT_FLAG, "struct" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_109 = { 6 | NIM_STRLIT_FLAG, "switch" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_110 = { 4 | NIM_STRLIT_FLAG, "this" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_111 = { 5 | NIM_STRLIT_FLAG, "throw" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_112 = { 7 | NIM_STRLIT_FLAG, "typedef" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_113 = { 5 | NIM_STRLIT_FLAG, "union" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_114 = { 8 | NIM_STRLIT_FLAG, "unsigned" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_115 = { 7 | NIM_STRLIT_FLAG, "virtual" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_116 = { 4 | NIM_STRLIT_FLAG, "void" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_117 = { 8 | NIM_STRLIT_FLAG, "volatile" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_118 = { 8 | NIM_STRLIT_FLAG, "abstract" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_119 = { 4 | NIM_STRLIT_FLAG, "base" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_120 = { 4 | NIM_STRLIT_FLAG, "bool" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_121 = { 4 | NIM_STRLIT_FLAG, "byte" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_122 = { 7 | NIM_STRLIT_FLAG, "checked" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_123 = { 7 | NIM_STRLIT_FLAG, "decimal" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_124 = { 8 | NIM_STRLIT_FLAG, "delegate" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_125 = { 5 | NIM_STRLIT_FLAG, "event" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_126 = { 8 | NIM_STRLIT_FLAG, "explicit" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_127 = { 5 | NIM_STRLIT_FLAG, "false" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_128 = { 5 | NIM_STRLIT_FLAG, "fixed" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_129 = { 7 | NIM_STRLIT_FLAG, "foreach" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_130 = { 8 | NIM_STRLIT_FLAG, "implicit" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_131 = { 8 | NIM_STRLIT_FLAG, "internal" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_132 = { 4 | NIM_STRLIT_FLAG, "lock" };
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_133 = { 9 | NIM_STRLIT_FLAG, "namespace" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_134 = { 4 | NIM_STRLIT_FLAG, "null" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_135 = { 8 | NIM_STRLIT_FLAG, "override" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_136 = { 6 | NIM_STRLIT_FLAG, "params" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_137 = { 8 | NIM_STRLIT_FLAG, "readonly" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_138 = { 5 | NIM_STRLIT_FLAG, "sbyte" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_139 = { 6 | NIM_STRLIT_FLAG, "sealed" };
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_140 = { 10 | NIM_STRLIT_FLAG, "stackalloc" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_141 = { 6 | NIM_STRLIT_FLAG, "string" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_142 = { 4 | NIM_STRLIT_FLAG, "true" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_143 = { 6 | NIM_STRLIT_FLAG, "typeof" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_144 = { 4 | NIM_STRLIT_FLAG, "uint" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_145 = { 5 | NIM_STRLIT_FLAG, "ulong" };
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_146 = { 9 | NIM_STRLIT_FLAG, "unchecked" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_147 = { 6 | NIM_STRLIT_FLAG, "unsafe" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_148 = { 6 | NIM_STRLIT_FLAG, "ushort" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_149 = { 5 | NIM_STRLIT_FLAG, "_Bool" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_150 = { 8 | NIM_STRLIT_FLAG, "_Complex" };
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_151 = { 10 | NIM_STRLIT_FLAG, "_Imaginary" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_152 = { 8 | NIM_STRLIT_FLAG, "restrict" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_153 = { 6 | NIM_STRLIT_FLAG, "assert" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_154 = { 7 | NIM_STRLIT_FLAG, "boolean" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_155 = { 7 | NIM_STRLIT_FLAG, "extends" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_156 = { 5 | NIM_STRLIT_FLAG, "final" };
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_157 = { 10 | NIM_STRLIT_FLAG, "implements" };
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_158 = { 10 | NIM_STRLIT_FLAG, "instanceof" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_159 = { 6 | NIM_STRLIT_FLAG, "native" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_160 = { 7 | NIM_STRLIT_FLAG, "package" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_161 = { 8 | NIM_STRLIT_FLAG, "strictfp" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_162 = { 5 | NIM_STRLIT_FLAG, "super" };
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_163 = { 12 | NIM_STRLIT_FLAG, "synchronized" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_164 = { 6 | NIM_STRLIT_FLAG, "throws" };
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_165 = { 9 | NIM_STRLIT_FLAG, "transient" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_166 = { 5 | NIM_STRLIT_FLAG, "False" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_167 = { 4 | NIM_STRLIT_FLAG, "None" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_168 = { 4 | NIM_STRLIT_FLAG, "True" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_169 = { 5 | NIM_STRLIT_FLAG, "async" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_170 = { 5 | NIM_STRLIT_FLAG, "await" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_171 = { 3 | NIM_STRLIT_FLAG, "def" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_172 = { 3 | NIM_STRLIT_FLAG, "del" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_173 = { 6 | NIM_STRLIT_FLAG, "global" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_174 = { 6 | NIM_STRLIT_FLAG, "lambda" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_175 = { 8 | NIM_STRLIT_FLAG, "nonlocal" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_176 = { 4 | NIM_STRLIT_FLAG, "pass" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_177 = { 4 | NIM_STRLIT_FLAG, "with" };
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__0kVEnxqJYMmsZjjZ9a1FeBw_178 = {
0x01, 0x3e, 0x00, 0x00, 0xc5, 0x03, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_179 = { 3 | NIM_STRLIT_FLAG, "Eof" };
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_180 = { 10 | NIM_STRLIT_FLAG, "Whitespace" };
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_181 = { 9 | NIM_STRLIT_FLAG, "DecNumber" };
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_182 = { 9 | NIM_STRLIT_FLAG, "BinNumber" };
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_183 = { 9 | NIM_STRLIT_FLAG, "HexNumber" };
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_184 = { 9 | NIM_STRLIT_FLAG, "OctNumber" };
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_185 = { 11 | NIM_STRLIT_FLAG, "FloatNumber" };
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_186 = { 10 | NIM_STRLIT_FLAG, "Identifier" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_187 = { 7 | NIM_STRLIT_FLAG, "Keyword" };
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_188 = { 9 | NIM_STRLIT_FLAG, "StringLit" };
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_189 = { 13 | NIM_STRLIT_FLAG, "LongStringLit" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_190 = { 7 | NIM_STRLIT_FLAG, "CharLit" };
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_191 = { 14 | NIM_STRLIT_FLAG, "EscapeSequence" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_192 = { 8 | NIM_STRLIT_FLAG, "Operator" };
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_193 = { 11 | NIM_STRLIT_FLAG, "Punctuation" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_194 = { 7 | NIM_STRLIT_FLAG, "Comment" };
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_195 = { 11 | NIM_STRLIT_FLAG, "LongComment" };
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_196 = { 17 | NIM_STRLIT_FLAG, "RegularExpression" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_197 = { 8 | NIM_STRLIT_FLAG, "TagStart" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_198 = { 6 | NIM_STRLIT_FLAG, "TagEnd" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_199 = { 3 | NIM_STRLIT_FLAG, "Key" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_200 = { 5 | NIM_STRLIT_FLAG, "Value" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_201 = { 7 | NIM_STRLIT_FLAG, "RawData" };
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_202 = { 9 | NIM_STRLIT_FLAG, "Assembler" };
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_203 = { 12 | NIM_STRLIT_FLAG, "Preprocessor" };
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_204 = { 9 | NIM_STRLIT_FLAG, "Directive" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_205 = { 7 | NIM_STRLIT_FLAG, "Command" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_206 = { 4 | NIM_STRLIT_FLAG, "Rule" };
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_207 = { 9 | NIM_STRLIT_FLAG, "Hyperlink" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_208 = { 5 | NIM_STRLIT_FLAG, "Label" };
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_209 = { 9 | NIM_STRLIT_FLAG, "Reference" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_210 = { 6 | NIM_STRLIT_FLAG, "Prompt" };
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_211 = { 13 | NIM_STRLIT_FLAG, "ProgramOutput" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_212 = { 7 | NIM_STRLIT_FLAG, "program" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_213 = { 6 | NIM_STRLIT_FLAG, "option" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__0kVEnxqJYMmsZjjZ9a1FeBw_214 = { 5 | NIM_STRLIT_FLAG, "Other" };
N_LIB_PRIVATE NIM_CONST tyArray__wVkbv9aOuop9cKsgoz0aezKQ sourceLanguageToStr__packagesZdocutilsZhighlite_u68 = {{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_2},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_3},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_4},
{2, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_5},
{1, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_6},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_7},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_8},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_9},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_10},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_11}}
;
N_LIB_PRIVATE NIM_CONST tyArray__wVkbv9aOuop9cKsgoz0aezKQ sourceLanguageToAlpha__packagesZdocutilsZhighlite_u69 = {{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_2},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_3},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_12},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_13},
{1, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_6},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_7},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_8},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_9},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_10},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_11}}
;
N_LIB_PRIVATE NIM_CONST tyArray__W7G5m750XsEydrrdcBFnuA nimKeywords__packagesZdocutilsZhighlite_u71 = {{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_17},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_18},
{2, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_19},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_20},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_21},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_22},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_23},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_24},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_25},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_26},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_27},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_28},
{9, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_29},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_30},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_31},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_32},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_33},
{2, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_34},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_35},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_36},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_37},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_38},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_39},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_40},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_41},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_42},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_43},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_44},
{2, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_45},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_46},
{2, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_47},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_48},
{9, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_49},
{2, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_50},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_51},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_52},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_53},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_54},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_55},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_56},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_57},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_58},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_59},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_60},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_61},
{2, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_62},
{2, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_63},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_64},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_65},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_66},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_67},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_68},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_69},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_70},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_71},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_72},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_73},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_74},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_75},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_76},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_77},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_78},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_79},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_80},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_81},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_82}}
;
N_LIB_PRIVATE NIM_CONST tyArray__cLKWlXEmBJfDEe4kfvzxkw keywords__packagesZdocutilsZhighlite_u1229 = {{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_20},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_85},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_23},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_24},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_86},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_87},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_88},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_27},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_28},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_89},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_90},
{2, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_34},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_91},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_36},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_38},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_92},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_93},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_42},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_94},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_95},
{2, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_45},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_96},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_97},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_98},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_99},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_100},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_101},
{9, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_102},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_103},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_104},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_69},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_105},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_106},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_107},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_72},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_108},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_109},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_73},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_110},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_111},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_74},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_112},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_113},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_114},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_115},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_116},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_117},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_80}}
;
N_LIB_PRIVATE NIM_CONST tyArray__NwaMkOW9b1iUX9bIMAHgGTww keywords__packagesZdocutilsZhighlite_u1269 = {{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_118},
{2, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_19},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_119},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_120},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_23},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_121},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_24},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_86},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_87},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_122},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_88},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_27},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_28},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_123},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_89},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_124},
{2, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_34},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_91},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_36},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_38},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_125},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_126},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_92},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_127},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_41},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_128},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_93},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_42},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_129},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_95},
{2, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_45},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_130},
{2, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_47},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_97},
{9, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_49},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_131},
{2, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_50},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_132},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_98},
{9, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_133},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_99},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_134},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_61},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_100},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_64},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_135},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_136},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_101},
{9, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_102},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_103},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_137},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_68},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_69},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_138},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_139},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_105},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_107},
{10, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_140},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_72},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_141},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_108},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_109},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_110},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_111},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_142},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_74},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_143},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_144},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_145},
{9, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_146},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_147},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_148},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_77},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_115},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_116},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_117},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_80}}
;
N_LIB_PRIVATE NIM_CONST tyArray__7aIKux9btsNssxB8Y2FsvcA keywords__packagesZdocutilsZhighlite_u1189 = {{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_149},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_150},
{10, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_151},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_85},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_23},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_24},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_87},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_27},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_28},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_89},
{2, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_34},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_91},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_36},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_38},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_92},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_93},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_42},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_95},
{2, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_45},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_96},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_97},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_98},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_104},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_152},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_69},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_105},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_106},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_107},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_72},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_108},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_109},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_112},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_113},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_114},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_116},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_117},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_80}}
;
N_LIB_PRIVATE NIM_CONST tyArray__n9aEI9bb6tgFT8eY9a5zR4szA keywords__packagesZdocutilsZhighlite_u1309 = {{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_118},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_153},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_154},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_23},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_121},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_24},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_86},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_87},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_88},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_27},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_28},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_89},
{2, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_34},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_91},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_36},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_38},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_155},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_127},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_156},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_41},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_93},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_42},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_95},
{2, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_45},
{10, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_157},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_46},
{10, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_158},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_97},
{9, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_49},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_98},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_159},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_99},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_134},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_160},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_101},
{9, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_102},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_103},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_69},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_105},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_72},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_161},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_162},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_109},
{12, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_163},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_110},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_111},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_164},
{9, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_165},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_142},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_74},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_116},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_117},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_80}}
;
N_LIB_PRIVATE NIM_CONST tyArray__mlDDS9c5sg9beP8qh9bHeHuiQ keywords__packagesZdocutilsZhighlite_u1982 = {{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_166},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_167},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_168},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_18},
{2, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_19},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_153},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_169},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_170},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_23},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_88},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_28},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_171},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_172},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_35},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_36},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_39},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_41},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_42},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_43},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_173},
{2, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_45},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_46},
{2, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_47},
{2, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_50},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_174},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_175},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_59},
{2, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_63},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_176},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_67},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_69},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_74},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_80},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_177},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_82}}
;
N_LIB_PRIVATE NIM_CONST tyArray__9amQAAkHuxu9cNghyKvw0urQ tokenClassToStr__packagesZdocutilsZhighlite_u70 = {{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_179},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_167},
{10, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_180},
{9, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_181},
{9, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_182},
{9, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_183},
{9, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_184},
{11, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_185},
{10, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_186},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_187},
{9, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_188},
{13, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_189},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_190},
{14, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_191},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_192},
{11, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_193},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_194},
{11, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_195},
{17, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_196},
{8, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_197},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_198},
{3, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_199},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_200},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_201},
{9, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_202},
{12, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_203},
{9, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_204},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_205},
{4, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_206},
{9, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_207},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_208},
{9, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_209},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_210},
{13, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_211},
{7, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_212},
{6, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_213},
{5, (NimStrPayload*)&TM__0kVEnxqJYMmsZjjZ9a1FeBw_214}}
;
extern NIM_BOOL nimInErrorMode__system_u4143;
static NIM_CONST NU32 TM__0kVEnxqJYMmsZjjZ9a1FeBw_14[2] = {3701606400, 3382059520};
N_LIB_PRIVATE TNimTypeV2 NTIv2__t8mWIshWZpNBbL0h6CSV0g_ = {.destructor = (void*)NIM_NIL, .size = sizeof(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g), .align = (NI16) NIM_ALIGNOF(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g), .depth = 1, .display = TM__0kVEnxqJYMmsZjjZ9a1FeBw_14, .traceImpl = (void*)NIM_NIL, .flags = 0};
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4143);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA, getSourceLanguage__packagesZdocutilsZhighlite_u72)(NimStringV2 name_p0) {
	tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA i_1;
		NI res_1;
		i_1 = (tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA)0;
		res_1 = ((NI)1);
		{
			while (1) {
				if (!(res_1 <= ((NI)9))) goto LA3;
				i_1 = ((tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA) (res_1));
				{
					NI T6_;
					T6_ = (NI)0;
					T6_ = nsuCmpIgnoreStyle(name_p0, sourceLanguageToStr__packagesZdocutilsZhighlite_u68[(i_1)- 0]);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!(T6_ == ((NI)0))) goto LA7_;
					result = i_1;
					goto BeforeRet_;
				}
LA7_: ;
				{
					NI T11_;
					T11_ = (NI)0;
					T11_ = nsuCmpIgnoreStyle(name_p0, sourceLanguageToAlpha__packagesZdocutilsZhighlite_u69[(i_1)- 0]);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!(T11_ == ((NI)0))) goto LA12_;
					result = i_1;
					goto BeforeRet_;
				}
LA12_: ;
				res_1 += ((NI)1);
			} LA3: ;
		}
	}
	result = ((tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA)0);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, initGeneralTokenizer__packagesZdocutilsZhighlite_u120)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0, NCSTRING buf_p1) {
	(*g_p0).buf = buf_p1;
	(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)0);
	(*g_p0).start = ((NI)0);
	(*g_p0).length = ((NI)0);
	(*g_p0).state = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)0);
	(*g_p0).lang = ((tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA)0);
	(*g_p0).pos = ((NI)0);
}
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringV2 s_p0) {
	NCSTRING result;
	{
		if (!(s_p0.len == ((NI)0))) goto LA3_;
		result = "";
	}
	goto LA1_;
LA3_: ;
	{
		result = ((NCSTRING) ((*s_p0.p).data));
	}
LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, initGeneralTokenizer__packagesZdocutilsZhighlite_u154)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0, NimStringV2 buf_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	initGeneralTokenizer__packagesZdocutilsZhighlite_u120(g_p0, nimToCStringConv(buf_p1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(void, nimAddCharV1)(NimStringV2* s_p0, NIM_CHAR c_p1) {
	prepareAdd(s_p0, ((NI)1));
	(*(*s_p0).p).data[(*s_p0).len] = c_p1;
	(*s_p0).len += ((NI)1);
	(*(*s_p0).p).data[(*s_p0).len] = 0;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA, nimGetKeyword__packagesZdocutilsZhighlite_u159)(NimStringV2 id_p0) {
	tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NimStringV2 k_1;
		NI i_1;
		k_1.len = 0; k_1.p = NIM_NIL;
		i_1 = ((NI)0);
		{
			while (1) {
				k_1 = nimKeywords__packagesZdocutilsZhighlite_u71[(i_1)- 0];
				{
					NI T6_;
					T6_ = (NI)0;
					T6_ = nsuCmpIgnoreStyle(id_p0, k_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!(T6_ == ((NI)0))) goto LA7_;
					result = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)9);
					goto BeforeRet_;
				}
LA7_: ;
				{
					if (!(((NI)65) <= i_1)) goto LA11_;
					goto LA2;
				}
LA11_: ;
				i_1 += ((NI)1);
			}
		} LA2: ;
	}
	result = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)8);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, isKeyword__packagesZdocutilsZhighlite_u358)(NimStringV2* x_p0, NI x_p0Len_0, NimStringV2 y_p1) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	result = binarySearch__packagesZdocutilsZhighlite_u362(x_p0, x_p0Len_0, y_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, nimNumberPostfix__packagesZdocutilsZhighlite_u245)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0, NI position_p1) {
	NI result;
	NI pos_1;
	pos_1 = position_p1;
	{
		if (!((NU8)((*g_p0).buf[pos_1]) == (NU8)(39))) goto LA3_;
		pos_1 += ((NI)1);
		switch (((NU8)((*g_p0).buf[pos_1]))) {
		case 102:
		case 70:
		{
			(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)7);
			pos_1 += ((NI)1);
			{
				if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(57)))) goto LA8_;
				pos_1 += ((NI)1);
			}
LA8_: ;
			{
				if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(57)))) goto LA12_;
				pos_1 += ((NI)1);
			}
LA12_: ;
		}
		break;
		case 105:
		case 73:
		{
			pos_1 += ((NI)1);
			{
				if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(57)))) goto LA17_;
				pos_1 += ((NI)1);
			}
LA17_: ;
			{
				if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(57)))) goto LA21_;
				pos_1 += ((NI)1);
			}
LA21_: ;
		}
		break;
		default:
		{
		}
		break;
		}
	}
LA3_: ;
	result = pos_1;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, nimNumber__packagesZdocutilsZhighlite_u301)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0, NI position_p1) {
	NI result;
	NI pos_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	pos_1 = position_p1;
	(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)3);
	{
		while (1) {
			if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(57)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(95)))) goto LA2;
			pos_1 += ((NI)1);
		} LA2: ;
	}
	{
		if (!((NU8)((*g_p0).buf[pos_1]) == (NU8)(46))) goto LA5_;
		(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)7);
		pos_1 += ((NI)1);
		{
			while (1) {
				if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(57)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(95)))) goto LA8;
				pos_1 += ((NI)1);
			} LA8: ;
		}
	}
LA5_: ;
	{
		if (!(((NU8)((*g_p0).buf[pos_1])) == ((NU8)(101)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(69)))) goto LA11_;
		(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)7);
		pos_1 += ((NI)1);
		{
			if (!(((NU8)((*g_p0).buf[pos_1])) == ((NU8)(43)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(45)))) goto LA15_;
			pos_1 += ((NI)1);
		}
LA15_: ;
		{
			while (1) {
				if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(57)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(95)))) goto LA18;
				pos_1 += ((NI)1);
			} LA18: ;
		}
	}
LA11_: ;
	result = nimNumberPostfix__packagesZdocutilsZhighlite_u245(g_p0, pos_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, nimNextToken__packagesZdocutilsZhighlite_u404)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0, NimStringV2* keywords_p1, NI keywords_p1Len_0) {
	NI pos_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	pos_1 = (*g_p0).pos;
	(*g_p0).start = (*g_p0).pos;
	{
		if (!((*g_p0).state == ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)10))) goto LA3_;
		{
			if (!((NU8)((*g_p0).buf[pos_1]) == (NU8)(92))) goto LA7_;
			(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)13);
			pos_1 += ((NI)1);
			switch (((NU8)((*g_p0).buf[pos_1]))) {
			case 120:
			case 88:
			{
				pos_1 += ((NI)1);
				{
					if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(57)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(65)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(70)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(97)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(102)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(95)))) goto LA12_;
					pos_1 += ((NI)1);
				}
LA12_: ;
				{
					if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(57)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(65)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(70)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(97)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(102)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(95)))) goto LA16_;
					pos_1 += ((NI)1);
				}
LA16_: ;
			}
			break;
			case 48 ... 57:
			{
				{
					while (1) {
						if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(57)))) goto LA20;
						pos_1 += ((NI)1);
					} LA20: ;
				}
			}
			break;
			case 0:
			{
				(*g_p0).state = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)1);
			}
			break;
			default:
			{
				pos_1 += ((NI)1);
			}
			break;
			}
		}
		goto LA5_;
LA7_: ;
		{
			(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)10);
			{
				while (1) {
					switch (((NU8)((*g_p0).buf[pos_1]))) {
					case 92:
					{
						goto LA24;
					}
					break;
					case 0:
					case 13:
					case 10:
					{
						(*g_p0).state = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)1);
						goto LA24;
					}
					break;
					case 34:
					{
						pos_1 += ((NI)1);
						(*g_p0).state = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)1);
						goto LA24;
					}
					break;
					default:
					{
						pos_1 += ((NI)1);
					}
					break;
					}
				}
			} LA24: ;
		}
LA5_: ;
	}
	goto LA1_;
LA3_: ;
	{
		switch (((NU8)((*g_p0).buf[pos_1]))) {
		case 32:
		case 9 ... 13:
		{
			(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)2);
			{
				while (1) {
					if (!(((NU8)((*g_p0).buf[pos_1])) == ((NU8)(32)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(9)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(13)))) goto LA33;
					pos_1 += ((NI)1);
				} LA33: ;
			}
		}
		break;
		case 35:
		{
			NIM_BOOL isDoc_1;
			(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)16);
			pos_1 += ((NI)1);
			isDoc_1 = NIM_FALSE;
			{
				if (!((NU8)((*g_p0).buf[pos_1]) == (NU8)(35))) goto LA37_;
				pos_1 += ((NI)1);
				isDoc_1 = NIM_TRUE;
			}
LA37_: ;
			{
				NIM_BOOL T41_;
				NI nesting_1;
				T41_ = (NIM_BOOL)0;
				T41_ = ((NU8)((*g_p0).buf[pos_1]) == (NU8)(91));
				if (!(T41_)) goto LA42_;
				T41_ = ((*g_p0).lang == ((tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA)1));
LA42_: ;
				if (!T41_) goto LA43_;
				(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)17);
				nesting_1 = ((NI)0);
				{
					while (1) {
						switch (((NU8)((*g_p0).buf[pos_1]))) {
						case 0:
						{
							goto LA45;
						}
						break;
						case 35:
						{
							{
								if (!isDoc_1) goto LA51_;
								{
									NIM_BOOL T55_;
									T55_ = (NIM_BOOL)0;
									T55_ = ((NU8)((*g_p0).buf[(NI)(pos_1 + ((NI)1))]) == (NU8)(35));
									if (!(T55_)) goto LA56_;
									T55_ = ((NU8)((*g_p0).buf[(NI)(pos_1 + ((NI)2))]) == (NU8)(91));
LA56_: ;
									if (!T55_) goto LA57_;
									nesting_1 += ((NI)1);
								}
LA57_: ;
							}
							goto LA49_;
LA51_: ;
							{
								if (!((NU8)((*g_p0).buf[(NI)(pos_1 + ((NI)1))]) == (NU8)(91))) goto LA60_;
								nesting_1 += ((NI)1);
							}
							goto LA49_;
LA60_: ;
LA49_: ;
							pos_1 += ((NI)1);
						}
						break;
						case 93:
						{
							{
								if (!isDoc_1) goto LA65_;
								{
									NIM_BOOL T69_;
									T69_ = (NIM_BOOL)0;
									T69_ = ((NU8)((*g_p0).buf[(NI)(pos_1 + ((NI)1))]) == (NU8)(35));
									if (!(T69_)) goto LA70_;
									T69_ = ((NU8)((*g_p0).buf[(NI)(pos_1 + ((NI)2))]) == (NU8)(35));
LA70_: ;
									if (!T69_) goto LA71_;
									{
										if (!(nesting_1 == ((NI)0))) goto LA75_;
										pos_1 += ((NI)3);
										goto LA45;
									}
LA75_: ;
									nesting_1 -= ((NI)1);
								}
LA71_: ;
							}
							goto LA63_;
LA65_: ;
							{
								if (!((NU8)((*g_p0).buf[(NI)(pos_1 + ((NI)1))]) == (NU8)(35))) goto LA78_;
								{
									if (!(nesting_1 == ((NI)0))) goto LA82_;
									pos_1 += ((NI)2);
									goto LA45;
								}
LA82_: ;
								nesting_1 -= ((NI)1);
							}
							goto LA63_;
LA78_: ;
LA63_: ;
							pos_1 += ((NI)1);
						}
						break;
						default:
						{
							pos_1 += ((NI)1);
						}
						break;
						}
					}
				} LA45: ;
			}
			goto LA39_;
LA43_: ;
			{
				{
					while (1) {
						if (!!((((NU8)((*g_p0).buf[pos_1])) == ((NU8)(0)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(10)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(13))))) goto LA87;
						pos_1 += ((NI)1);
					} LA87: ;
				}
			}
LA39_: ;
		}
		break;
		case 97 ... 122:
		case 65 ... 90:
		case 95:
		case 128 ... 255:
		{
			NimStringV2 id_1;
			id_1.len = 0; id_1.p = NIM_NIL;
			id_1 = TM__0kVEnxqJYMmsZjjZ9a1FeBw_16;
			{
				while (1) {
					if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(57)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(65)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(90)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(95)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(97)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(122)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(128)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(255)))) goto LA91;
					nimAddCharV1((&id_1), (*g_p0).buf[pos_1]);
					pos_1 += ((NI)1);
				} LA91: ;
			}
			{
				if (!((NU8)((*g_p0).buf[pos_1]) == (NU8)(34))) goto LA94_;
				{
					NIM_BOOL T98_;
					T98_ = (NIM_BOOL)0;
					T98_ = ((NU8)((*g_p0).buf[(NI)(pos_1 + ((NI)1))]) == (NU8)(34));
					if (!(T98_)) goto LA99_;
					T98_ = ((NU8)((*g_p0).buf[(NI)(pos_1 + ((NI)2))]) == (NU8)(34));
LA99_: ;
					if (!T98_) goto LA100_;
					pos_1 += ((NI)3);
					(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)11);
					{
						while (1) {
							switch (((NU8)((*g_p0).buf[pos_1]))) {
							case 0:
							{
								goto LA102;
							}
							break;
							case 34:
							{
								pos_1 += ((NI)1);
								{
									NIM_BOOL T108_;
									NIM_BOOL T109_;
									T108_ = (NIM_BOOL)0;
									T109_ = (NIM_BOOL)0;
									T109_ = ((NU8)((*g_p0).buf[pos_1]) == (NU8)(34));
									if (!(T109_)) goto LA110_;
									T109_ = ((NU8)((*g_p0).buf[(NI)(pos_1 + ((NI)1))]) == (NU8)(34));
LA110_: ;
									T108_ = T109_;
									if (!(T108_)) goto LA111_;
									T108_ = !(((NU8)((*g_p0).buf[(NI)(pos_1 + ((NI)2))]) == (NU8)(34)));
LA111_: ;
									if (!T108_) goto LA112_;
									pos_1 += ((NI)2);
									goto LA102;
								}
LA112_: ;
							}
							break;
							default:
							{
								pos_1 += ((NI)1);
							}
							break;
							}
						}
					} LA102: ;
				}
				goto LA96_;
LA100_: ;
				{
					(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)23);
					pos_1 += ((NI)1);
					{
						while (1) {
							if (!!((((NU8)((*g_p0).buf[pos_1])) == ((NU8)(0)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(10)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(13))))) goto LA117;
							{
								NIM_BOOL T120_;
								T120_ = (NIM_BOOL)0;
								T120_ = ((NU8)((*g_p0).buf[pos_1]) == (NU8)(34));
								if (!(T120_)) goto LA121_;
								T120_ = !(((NU8)((*g_p0).buf[(NI)(pos_1 + ((NI)1))]) == (NU8)(34)));
LA121_: ;
								if (!T120_) goto LA122_;
								goto LA116;
							}
LA122_: ;
							pos_1 += ((NI)1);
						} LA117: ;
					} LA116: ;
					{
						if (!((NU8)((*g_p0).buf[pos_1]) == (NU8)(34))) goto LA126_;
						pos_1 += ((NI)1);
					}
LA126_: ;
				}
LA96_: ;
			}
			goto LA92_;
LA94_: ;
			{
				{
					tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA T133_;
					if (!((*g_p0).lang == ((tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA)1))) goto LA131_;
					T133_ = (tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)0;
					T133_ = nimGetKeyword__packagesZdocutilsZhighlite_u159(id_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
					(*g_p0).kind = T133_;
				}
				goto LA129_;
LA131_: ;
				{
					NI T135_;
					T135_ = (NI)0;
					T135_ = isKeyword__packagesZdocutilsZhighlite_u358(keywords_p1, keywords_p1Len_0, id_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
					if (!(((NI)0) <= T135_)) goto LA136_;
					(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)9);
				}
				goto LA129_;
LA136_: ;
				{
					(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)8);
				}
LA129_: ;
			}
LA92_: ;
			{
				LA89_:;
			}
			{
				eqdestroy___system_u2691(id_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		case 48:
		{
			pos_1 += ((NI)1);
			switch (((NU8)((*g_p0).buf[pos_1]))) {
			case 98:
			case 66:
			{
				(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)4);
				pos_1 += ((NI)1);
				{
					while (1) {
						if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(49)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(95)))) goto LA144;
						pos_1 += ((NI)1);
					} LA144: ;
				}
				pos_1 = nimNumberPostfix__packagesZdocutilsZhighlite_u245(g_p0, pos_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
			break;
			case 120:
			case 88:
			{
				(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)5);
				pos_1 += ((NI)1);
				{
					while (1) {
						if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(57)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(65)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(70)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(97)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(102)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(95)))) goto LA147;
						pos_1 += ((NI)1);
					} LA147: ;
				}
				pos_1 = nimNumberPostfix__packagesZdocutilsZhighlite_u245(g_p0, pos_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
			break;
			case 111:
			case 79:
			{
				(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)6);
				pos_1 += ((NI)1);
				{
					while (1) {
						if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(55)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(95)))) goto LA150;
						pos_1 += ((NI)1);
					} LA150: ;
				}
				pos_1 = nimNumberPostfix__packagesZdocutilsZhighlite_u245(g_p0, pos_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
			break;
			default:
			{
				pos_1 = nimNumber__packagesZdocutilsZhighlite_u301(g_p0, pos_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
			break;
			}
		}
		break;
		case 49 ... 57:
		{
			pos_1 = nimNumber__packagesZdocutilsZhighlite_u301(g_p0, pos_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		case 39:
		{
			NIM_BOOL followsBacktick_1;
			NIM_BOOL T154_;
			pos_1 += ((NI)1);
			T154_ = (NIM_BOOL)0;
			T154_ = (((NI)2) <= pos_1);
			if (!(T154_)) goto LA155_;
			T154_ = ((NU8)((*g_p0).buf[(NI)(pos_1 - ((NI)2))]) == (NU8)(96));
LA155_: ;
			followsBacktick_1 = T154_;
			{
				if (!!(followsBacktick_1)) goto LA158_;
				(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)12);
				{
					while (1) {
						switch (((NU8)((*g_p0).buf[pos_1]))) {
						case 0:
						case 13:
						case 10:
						{
							goto LA160;
						}
						break;
						case 39:
						{
							pos_1 += ((NI)1);
							goto LA160;
						}
						break;
						case 92:
						{
							pos_1 += ((NI)2);
						}
						break;
						default:
						{
							pos_1 += ((NI)1);
						}
						break;
						}
					}
				} LA160: ;
			}
			goto LA156_;
LA158_: ;
			{
				(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)15);
			}
LA156_: ;
		}
		break;
		case 34:
		{
			pos_1 += ((NI)1);
			{
				NIM_BOOL T170_;
				T170_ = (NIM_BOOL)0;
				T170_ = ((NU8)((*g_p0).buf[pos_1]) == (NU8)(34));
				if (!(T170_)) goto LA171_;
				T170_ = ((NU8)((*g_p0).buf[(NI)(pos_1 + ((NI)1))]) == (NU8)(34));
LA171_: ;
				if (!T170_) goto LA172_;
				pos_1 += ((NI)2);
				(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)11);
				{
					while (1) {
						switch (((NU8)((*g_p0).buf[pos_1]))) {
						case 0:
						{
							goto LA174;
						}
						break;
						case 34:
						{
							pos_1 += ((NI)1);
							{
								NIM_BOOL T180_;
								NIM_BOOL T181_;
								T180_ = (NIM_BOOL)0;
								T181_ = (NIM_BOOL)0;
								T181_ = ((NU8)((*g_p0).buf[pos_1]) == (NU8)(34));
								if (!(T181_)) goto LA182_;
								T181_ = ((NU8)((*g_p0).buf[(NI)(pos_1 + ((NI)1))]) == (NU8)(34));
LA182_: ;
								T180_ = T181_;
								if (!(T180_)) goto LA183_;
								T180_ = !(((NU8)((*g_p0).buf[(NI)(pos_1 + ((NI)2))]) == (NU8)(34)));
LA183_: ;
								if (!T180_) goto LA184_;
								pos_1 += ((NI)2);
								goto LA174;
							}
LA184_: ;
						}
						break;
						default:
						{
							pos_1 += ((NI)1);
						}
						break;
						}
					}
				} LA174: ;
			}
			goto LA168_;
LA172_: ;
			{
				(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)10);
				{
					while (1) {
						switch (((NU8)((*g_p0).buf[pos_1]))) {
						case 0:
						case 13:
						case 10:
						{
							goto LA188;
						}
						break;
						case 34:
						{
							pos_1 += ((NI)1);
							goto LA188;
						}
						break;
						case 92:
						{
							(*g_p0).state = (*g_p0).kind;
							goto LA188;
						}
						break;
						default:
						{
							pos_1 += ((NI)1);
						}
						break;
						}
					}
				} LA188: ;
			}
LA168_: ;
		}
		break;
		case 40:
		case 41:
		case 91:
		case 93:
		case 123:
		case 125:
		case 96:
		case 58:
		case 44:
		case 59:
		{
			pos_1 += ((NI)1);
			(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)15);
		}
		break;
		case 0:
		{
			(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)0);
		}
		break;
		default:
		{
			{
				if (!((TM__0kVEnxqJYMmsZjjZ9a1FeBw_83[(NU)((((NU8)((*g_p0).buf[pos_1]))))>>3] &(1U<<((NU)((((NU8)((*g_p0).buf[pos_1]))))&7U)))!=0)) goto LA199_;
				(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)14);
				{
					while (1) {
						if (!((TM__0kVEnxqJYMmsZjjZ9a1FeBw_83[(NU)((((NU8)((*g_p0).buf[pos_1]))))>>3] &(1U<<((NU)((((NU8)((*g_p0).buf[pos_1]))))&7U)))!=0)) goto LA202;
						pos_1 += ((NI)1);
					} LA202: ;
				}
			}
			goto LA197_;
LA199_: ;
			{
				pos_1 += ((NI)1);
				(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)1);
			}
LA197_: ;
		}
		break;
		}
	}
LA1_: ;
	(*g_p0).length = (NI)(pos_1 - (*g_p0).pos);
	{
		NIM_BOOL T206_;
		NIM_BOOL T207_;
		T206_ = (NIM_BOOL)0;
		T207_ = (NIM_BOOL)0;
		T207_ = !(((*g_p0).kind == ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)0)));
		if (!(T207_)) goto LA208_;
		T207_ = !(((*g_p0).state == ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)1)));
LA208_: ;
		T206_ = T207_;
		if (!(T206_)) goto LA209_;
		T206_ = ((*g_p0).length <= ((NI)0));
LA209_: ;
		if (!T206_) goto LA210_;
	}
LA210_: ;
	(*g_p0).pos = pos_1;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, generalNumber__packagesZdocutilsZhighlite_u747)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0, NI position_p1) {
	NI result;
	NI pos_1;
	pos_1 = position_p1;
	(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)3);
	{
		while (1) {
			if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(57)))) goto LA2;
			pos_1 += ((NI)1);
		} LA2: ;
	}
	{
		if (!((NU8)((*g_p0).buf[pos_1]) == (NU8)(46))) goto LA5_;
		(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)7);
		pos_1 += ((NI)1);
		{
			while (1) {
				if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(57)))) goto LA8;
				pos_1 += ((NI)1);
			} LA8: ;
		}
	}
LA5_: ;
	{
		if (!(((NU8)((*g_p0).buf[pos_1])) == ((NU8)(101)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(69)))) goto LA11_;
		(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)7);
		pos_1 += ((NI)1);
		{
			if (!(((NU8)((*g_p0).buf[pos_1])) == ((NU8)(43)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(45)))) goto LA15_;
			pos_1 += ((NI)1);
		}
LA15_: ;
		{
			while (1) {
				if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(57)))) goto LA18;
				pos_1 += ((NI)1);
			} LA18: ;
		}
	}
LA11_: ;
	result = pos_1;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, generalStrLit__packagesZdocutilsZhighlite_u803)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0, NI position_p1) {
	NI result;
	NI pos_1;
	NIM_CHAR c_1;
	pos_1 = position_p1;
	(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)10);
	c_1 = (*g_p0).buf[pos_1];
	pos_1 += ((NI)1);
	{
		while (1) {
			switch (((NU8)((*g_p0).buf[pos_1]))) {
			case 0:
			{
				goto LA1;
			}
			break;
			case 92:
			{
				pos_1 += ((NI)1);
				switch (((NU8)((*g_p0).buf[pos_1]))) {
				case 0:
				{
					goto LA1;
				}
				break;
				case 48 ... 57:
				{
					{
						while (1) {
							if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(57)))) goto LA8;
							pos_1 += ((NI)1);
						} LA8: ;
					}
				}
				break;
				case 120:
				case 88:
				{
					pos_1 += ((NI)1);
					{
						if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(57)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(65)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(70)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(97)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(102)))) goto LA12_;
						pos_1 += ((NI)1);
					}
LA12_: ;
					{
						if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(57)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(65)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(70)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(97)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(102)))) goto LA16_;
						pos_1 += ((NI)1);
					}
LA16_: ;
				}
				break;
				default:
				{
					pos_1 += ((NI)2);
				}
				break;
				}
			}
			break;
			default:
			{
				{
					if (!((NU8)((*g_p0).buf[pos_1]) == (NU8)(c_1))) goto LA22_;
					pos_1 += ((NI)1);
					goto LA1;
				}
				goto LA20_;
LA22_: ;
				{
					pos_1 += ((NI)1);
				}
LA20_: ;
			}
			break;
			}
		}
	} LA1: ;
	result = pos_1;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, clikeNextToken__packagesZdocutilsZhighlite_u875)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0, NimStringV2* keywords_p1, NI keywords_p1Len_0, tySet_tyEnum_TokenizerFlag__3fe5tVd800nlQ3htR4f9cXw flags_p2) {
	NI pos_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	pos_1 = (*g_p0).pos;
	(*g_p0).start = (*g_p0).pos;
	{
		if (!((*g_p0).state == ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)10))) goto LA3_;
		(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)10);
		{
			while (1) {
				switch (((NU8)((*g_p0).buf[pos_1]))) {
				case 92:
				{
					(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)13);
					pos_1 += ((NI)1);
					switch (((NU8)((*g_p0).buf[pos_1]))) {
					case 120:
					case 88:
					{
						pos_1 += ((NI)1);
						{
							if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(57)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(65)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(70)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(97)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(102)))) goto LA11_;
							pos_1 += ((NI)1);
						}
LA11_: ;
						{
							if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(57)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(65)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(70)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(97)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(102)))) goto LA15_;
							pos_1 += ((NI)1);
						}
LA15_: ;
					}
					break;
					case 48 ... 57:
					{
						{
							while (1) {
								if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(57)))) goto LA19;
								pos_1 += ((NI)1);
							} LA19: ;
						}
					}
					break;
					case 0:
					{
						(*g_p0).state = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)1);
					}
					break;
					default:
					{
						pos_1 += ((NI)1);
					}
					break;
					}
					goto LA5;
				}
				break;
				case 0:
				case 13:
				case 10:
				{
					(*g_p0).state = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)1);
					goto LA5;
				}
				break;
				case 34:
				{
					pos_1 += ((NI)1);
					(*g_p0).state = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)1);
					goto LA5;
				}
				break;
				default:
				{
					pos_1 += ((NI)1);
				}
				break;
				}
			}
		} LA5: ;
	}
	goto LA1_;
LA3_: ;
	{
		switch (((NU8)((*g_p0).buf[pos_1]))) {
		case 32:
		case 9 ... 13:
		{
			(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)2);
			{
				while (1) {
					if (!(((NU8)((*g_p0).buf[pos_1])) == ((NU8)(32)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(9)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(13)))) goto LA28;
					pos_1 += ((NI)1);
				} LA28: ;
			}
		}
		break;
		case 47:
		{
			pos_1 += ((NI)1);
			{
				if (!((NU8)((*g_p0).buf[pos_1]) == (NU8)(47))) goto LA32_;
				(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)16);
				{
					while (1) {
						if (!!((((NU8)((*g_p0).buf[pos_1])) == ((NU8)(0)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(10)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(13))))) goto LA35;
						pos_1 += ((NI)1);
					} LA35: ;
				}
			}
			goto LA30_;
LA32_: ;
			{
				NI nested_1;
				if (!((NU8)((*g_p0).buf[pos_1]) == (NU8)(42))) goto LA37_;
				(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)17);
				nested_1 = ((NI)0);
				pos_1 += ((NI)1);
				{
					while (1) {
						switch (((NU8)((*g_p0).buf[pos_1]))) {
						case 42:
						{
							pos_1 += ((NI)1);
							{
								if (!((NU8)((*g_p0).buf[pos_1]) == (NU8)(47))) goto LA44_;
								pos_1 += ((NI)1);
								{
									if (!(nested_1 == ((NI)0))) goto LA48_;
									goto LA39;
								}
LA48_: ;
							}
LA44_: ;
						}
						break;
						case 47:
						{
							pos_1 += ((NI)1);
							{
								if (!((NU8)((*g_p0).buf[pos_1]) == (NU8)(42))) goto LA53_;
								pos_1 += ((NI)1);
								{
									if (!((flags_p2 &((NU8)1<<((NU)((((tyEnum_TokenizerFlag__3fe5tVd800nlQ3htR4f9cXw)1)))&7U)))!=0)) goto LA57_;
									nested_1 += ((NI)1);
								}
LA57_: ;
							}
LA53_: ;
						}
						break;
						case 0:
						{
							goto LA39;
						}
						break;
						default:
						{
							pos_1 += ((NI)1);
						}
						break;
						}
					}
				} LA39: ;
			}
			goto LA30_;
LA37_: ;
			{
				(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)14);
				{
					while (1) {
						if (!((TM__0kVEnxqJYMmsZjjZ9a1FeBw_83[(NU)((((NU8)((*g_p0).buf[pos_1]))))>>3] &(1U<<((NU)((((NU8)((*g_p0).buf[pos_1]))))&7U)))!=0)) goto LA63;
						pos_1 += ((NI)1);
					} LA63: ;
				}
			}
LA30_: ;
		}
		break;
		case 35:
		{
			pos_1 += ((NI)1);
			{
				if (!((flags_p2 &((NU8)1<<((NU)((((tyEnum_TokenizerFlag__3fe5tVd800nlQ3htR4f9cXw)0)))&7U)))!=0)) goto LA67_;
				(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)25);
				{
					while (1) {
						if (!(((NU8)((*g_p0).buf[pos_1])) == ((NU8)(32)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(9)))) goto LA70;
						pos_1 += ((NI)1);
					} LA70: ;
				}
				{
					while (1) {
						if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(65)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(90)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(97)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(122)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(57)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(95)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(128)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(255)))) goto LA72;
						pos_1 += ((NI)1);
					} LA72: ;
				}
			}
			goto LA65_;
LA67_: ;
			{
				(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)14);
			}
LA65_: ;
		}
		break;
		case 97 ... 122:
		case 65 ... 90:
		case 95:
		case 128 ... 255:
		{
			NimStringV2 id_1;
			id_1.len = 0; id_1.p = NIM_NIL;
			id_1 = TM__0kVEnxqJYMmsZjjZ9a1FeBw_84;
			{
				while (1) {
					if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(65)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(90)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(97)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(122)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(57)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(95)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(128)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(255)))) goto LA76;
					nimAddCharV1((&id_1), (*g_p0).buf[pos_1]);
					pos_1 += ((NI)1);
				} LA76: ;
			}
			{
				NI T79_;
				T79_ = (NI)0;
				T79_ = isKeyword__packagesZdocutilsZhighlite_u358(keywords_p1, keywords_p1Len_0, id_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!(((NI)0) <= T79_)) goto LA80_;
				(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)9);
			}
			goto LA77_;
LA80_: ;
			{
				(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)8);
			}
LA77_: ;
			eqdestroy___system_u2691(id_1);
		}
		break;
		case 48:
		{
			pos_1 += ((NI)1);
			switch (((NU8)((*g_p0).buf[pos_1]))) {
			case 98:
			case 66:
			{
				pos_1 += ((NI)1);
				{
					while (1) {
						if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(49)))) goto LA86;
						pos_1 += ((NI)1);
					} LA86: ;
				}
				{
					if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(65)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(90)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(97)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(122)))) goto LA89_;
					pos_1 += ((NI)1);
				}
LA89_: ;
			}
			break;
			case 120:
			case 88:
			{
				pos_1 += ((NI)1);
				{
					while (1) {
						if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(57)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(65)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(70)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(97)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(102)))) goto LA93;
						pos_1 += ((NI)1);
					} LA93: ;
				}
				{
					if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(65)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(90)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(97)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(122)))) goto LA96_;
					pos_1 += ((NI)1);
				}
LA96_: ;
			}
			break;
			case 48 ... 55:
			{
				pos_1 += ((NI)1);
				{
					while (1) {
						if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(55)))) goto LA100;
						pos_1 += ((NI)1);
					} LA100: ;
				}
				{
					if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(65)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(90)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(97)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(122)))) goto LA103_;
					pos_1 += ((NI)1);
				}
LA103_: ;
			}
			break;
			default:
			{
				pos_1 = generalNumber__packagesZdocutilsZhighlite_u747(g_p0, pos_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				{
					if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(65)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(90)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(97)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(122)))) goto LA108_;
					pos_1 += ((NI)1);
				}
LA108_: ;
			}
			break;
			}
		}
		break;
		case 49 ... 57:
		{
			pos_1 = generalNumber__packagesZdocutilsZhighlite_u747(g_p0, pos_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			{
				if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(65)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(90)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(97)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(122)))) goto LA113_;
				pos_1 += ((NI)1);
			}
LA113_: ;
		}
		break;
		case 39:
		{
			pos_1 = generalStrLit__packagesZdocutilsZhighlite_u803(g_p0, pos_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)12);
		}
		break;
		case 34:
		{
			pos_1 += ((NI)1);
			(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)10);
			{
				while (1) {
					switch (((NU8)((*g_p0).buf[pos_1]))) {
					case 0:
					{
						goto LA117;
					}
					break;
					case 34:
					{
						pos_1 += ((NI)1);
						goto LA117;
					}
					break;
					case 92:
					{
						(*g_p0).state = (*g_p0).kind;
						goto LA117;
					}
					break;
					default:
					{
						pos_1 += ((NI)1);
					}
					break;
					}
				}
			} LA117: ;
		}
		break;
		case 40:
		case 41:
		case 91:
		case 93:
		case 123:
		case 125:
		case 58:
		case 44:
		case 59:
		case 46:
		{
			pos_1 += ((NI)1);
			(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)15);
		}
		break;
		case 0:
		{
			(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)0);
		}
		break;
		default:
		{
			{
				if (!((TM__0kVEnxqJYMmsZjjZ9a1FeBw_83[(NU)((((NU8)((*g_p0).buf[pos_1]))))>>3] &(1U<<((NU)((((NU8)((*g_p0).buf[pos_1]))))&7U)))!=0)) goto LA128_;
				(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)14);
				{
					while (1) {
						if (!((TM__0kVEnxqJYMmsZjjZ9a1FeBw_83[(NU)((((NU8)((*g_p0).buf[pos_1]))))>>3] &(1U<<((NU)((((NU8)((*g_p0).buf[pos_1]))))&7U)))!=0)) goto LA131;
						pos_1 += ((NI)1);
					} LA131: ;
				}
			}
			goto LA126_;
LA128_: ;
			{
				pos_1 += ((NI)1);
				(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)1);
			}
LA126_: ;
		}
		break;
		}
	}
LA1_: ;
	(*g_p0).length = (NI)(pos_1 - (*g_p0).pos);
	{
		NIM_BOOL T135_;
		T135_ = (NIM_BOOL)0;
		T135_ = !(((*g_p0).kind == ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)0)));
		if (!(T135_)) goto LA136_;
		T135_ = ((*g_p0).length <= ((NI)0));
LA136_: ;
		if (!T135_) goto LA137_;
	}
LA137_: ;
	(*g_p0).pos = pos_1;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, cppNextToken__packagesZdocutilsZhighlite_u1227)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	clikeNextToken__packagesZdocutilsZhighlite_u875(g_p0, keywords__packagesZdocutilsZhighlite_u1229, 48, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, csharpNextToken__packagesZdocutilsZhighlite_u1267)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	clikeNextToken__packagesZdocutilsZhighlite_u875(g_p0, keywords__packagesZdocutilsZhighlite_u1269, 77, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, cNextToken__packagesZdocutilsZhighlite_u1187)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	clikeNextToken__packagesZdocutilsZhighlite_u875(g_p0, keywords__packagesZdocutilsZhighlite_u1189, 37, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, javaNextToken__packagesZdocutilsZhighlite_u1307)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0) {
	tySet_tyEnum_TokenizerFlag__3fe5tVd800nlQ3htR4f9cXw T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = 0;
	clikeNextToken__packagesZdocutilsZhighlite_u875(g_p0, keywords__packagesZdocutilsZhighlite_u1309, 53, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, contains__int128_u922)(tyObject_HSlice__O4ak9be9cxLOjU6hb2Qjt9bhA s_p0, NIM_CHAR value_p1) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = ((NU8)(s_p0.a) <= (NU8)(value_p1));
	if (!(T1_)) goto LA2_;
	T1_ = ((NU8)(value_p1) <= (NU8)(s_p0.b));
LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(tyObject_HSlice__O4ak9be9cxLOjU6hb2Qjt9bhA, dotdot___int128_u871)(NIM_CHAR a_p0, NIM_CHAR b_p1) {
	tyObject_HSlice__O4ak9be9cxLOjU6hb2Qjt9bhA result;
	result.a = a_p0;
	result.b = b_p1;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, yamlPlainStrLit__packagesZdocutilsZhighlite_u1347)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0, NI* pos_p1) {
	(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)10);
	{
		while (1) {
			if (!!((((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(0)) || ((NU8)((*g_p0).buf[(*pos_p1)])) >= ((NU8)(9)) && ((NU8)((*g_p0).buf[(*pos_p1)])) <= ((NU8)(13)) || ((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(44)) || ((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(93)) || ((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(125))))) goto LA2;
			{
				NIM_BOOL T5_;
				T5_ = (NIM_BOOL)0;
				T5_ = ((NU8)((*g_p0).buf[(*pos_p1)]) == (NU8)(58));
				if (!(T5_)) goto LA6_;
				T5_ = (((NU8)((*g_p0).buf[(NI)((*pos_p1) + ((NI)1))])) == ((NU8)(0)) || ((NU8)((*g_p0).buf[(NI)((*pos_p1) + ((NI)1))])) >= ((NU8)(9)) && ((NU8)((*g_p0).buf[(NI)((*pos_p1) + ((NI)1))])) <= ((NU8)(13)) || ((NU8)((*g_p0).buf[(NI)((*pos_p1) + ((NI)1))])) == ((NU8)(32)));
LA6_: ;
				if (!T5_) goto LA7_;
				goto LA1;
			}
LA7_: ;
			(*pos_p1) += ((NI)1);
		} LA2: ;
	} LA1: ;
}
N_LIB_PRIVATE N_NIMCALL(void, yamlPossibleNumber__packagesZdocutilsZhighlite_u1363)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0, NI* pos_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)1);
	{
		if (!((NU8)((*g_p0).buf[(*pos_p1)]) == (NU8)(45))) goto LA3_;
		(*pos_p1) += ((NI)1);
	}
LA3_: ;
	{
		if (!((NU8)((*g_p0).buf[(*pos_p1)]) == (NU8)(48))) goto LA7_;
		(*pos_p1) += ((NI)1);
	}
	goto LA5_;
LA7_: ;
	{
		tyObject_HSlice__O4ak9be9cxLOjU6hb2Qjt9bhA T10_;
		NIM_BOOL T11_;
		T10_ = dotdot___int128_u871(49, 57);
		T11_ = (NIM_BOOL)0;
		T11_ = contains__int128_u922(T10_, (*g_p0).buf[(*pos_p1)]);
		if (!T11_) goto LA12_;
		(*pos_p1) += ((NI)1);
		{
			while (1) {
				if (!(((NU8)((*g_p0).buf[(*pos_p1)])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[(*pos_p1)])) <= ((NU8)(57)))) goto LA15;
				(*pos_p1) += ((NI)1);
			} LA15: ;
		}
	}
	goto LA5_;
LA12_: ;
	{
		yamlPlainStrLit__packagesZdocutilsZhighlite_u1347(g_p0, pos_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA5_: ;
	{
		if (!((*g_p0).kind == ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)1))) goto LA19_;
		{
			if (!(((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(0)) || ((NU8)((*g_p0).buf[(*pos_p1)])) >= ((NU8)(9)) && ((NU8)((*g_p0).buf[(*pos_p1)])) <= ((NU8)(13)) || ((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(32)) || ((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(44)) || ((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(93)) || ((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(125)))) goto LA23_;
			(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)3);
		}
		goto LA21_;
LA23_: ;
		{
			if (!((NU8)((*g_p0).buf[(*pos_p1)]) == (NU8)(46))) goto LA26_;
			(*pos_p1) += ((NI)1);
			{
				if (!!((((NU8)((*g_p0).buf[(*pos_p1)])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[(*pos_p1)])) <= ((NU8)(57))))) goto LA30_;
				yamlPlainStrLit__packagesZdocutilsZhighlite_u1347(g_p0, pos_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
			goto LA28_;
LA30_: ;
			{
				{
					while (1) {
						if (!(((NU8)((*g_p0).buf[(*pos_p1)])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[(*pos_p1)])) <= ((NU8)(57)))) goto LA34;
						(*pos_p1) += ((NI)1);
					} LA34: ;
				}
				{
					if (!(((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(0)) || ((NU8)((*g_p0).buf[(*pos_p1)])) >= ((NU8)(9)) && ((NU8)((*g_p0).buf[(*pos_p1)])) <= ((NU8)(13)) || ((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(32)) || ((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(44)) || ((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(93)) || ((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(125)))) goto LA37_;
					(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)7);
				}
LA37_: ;
			}
LA28_: ;
		}
		goto LA21_;
LA26_: ;
LA21_: ;
		{
			if (!((*g_p0).kind == ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)1))) goto LA41_;
			{
				if (!(((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(101)) || ((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(69)))) goto LA45_;
				(*pos_p1) += ((NI)1);
				{
					if (!(((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(45)) || ((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(43)))) goto LA49_;
					(*pos_p1) += ((NI)1);
				}
LA49_: ;
				{
					if (!!((((NU8)((*g_p0).buf[(*pos_p1)])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[(*pos_p1)])) <= ((NU8)(57))))) goto LA53_;
					yamlPlainStrLit__packagesZdocutilsZhighlite_u1347(g_p0, pos_p1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
				goto LA51_;
LA53_: ;
				{
					{
						while (1) {
							if (!(((NU8)((*g_p0).buf[(*pos_p1)])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[(*pos_p1)])) <= ((NU8)(57)))) goto LA57;
							(*pos_p1) += ((NI)1);
						} LA57: ;
					}
					{
						if (!(((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(0)) || ((NU8)((*g_p0).buf[(*pos_p1)])) >= ((NU8)(9)) && ((NU8)((*g_p0).buf[(*pos_p1)])) <= ((NU8)(13)) || ((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(32)) || ((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(44)) || ((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(93)) || ((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(125)))) goto LA60_;
						(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)7);
					}
					goto LA58_;
LA60_: ;
					{
						yamlPlainStrLit__packagesZdocutilsZhighlite_u1347(g_p0, pos_p1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					}
LA58_: ;
				}
LA51_: ;
			}
			goto LA43_;
LA45_: ;
			{
				yamlPlainStrLit__packagesZdocutilsZhighlite_u1347(g_p0, pos_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA43_: ;
		}
LA41_: ;
	}
LA19_: ;
	{
		while (1) {
			if (!!((((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(0)) || ((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(44)) || ((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(93)) || ((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(125)) || ((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(10)) || ((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(13))))) goto LA65;
			(*pos_p1) += ((NI)1);
			{
				if (!!((((NU8)((*g_p0).buf[(*pos_p1)])) >= ((NU8)(9)) && ((NU8)((*g_p0).buf[(*pos_p1)])) <= ((NU8)(13)) || ((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(32)) || ((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(44)) || ((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(93)) || ((NU8)((*g_p0).buf[(*pos_p1)])) == ((NU8)(125))))) goto LA68_;
				yamlPlainStrLit__packagesZdocutilsZhighlite_u1347(g_p0, pos_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				goto LA64;
			}
LA68_: ;
		} LA65: ;
	} LA64: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, yamlNextToken__packagesZdocutilsZhighlite_u1485)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0) {
	NI pos_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	pos_1 = (*g_p0).pos;
	(*g_p0).start = (*g_p0).pos;
	{
		if (!((*g_p0).state == ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)10))) goto LA3_;
		(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)10);
		{
			while (1) {
				switch (((NU8)((*g_p0).buf[pos_1]))) {
				case 92:
				{
					{
						if (!!((pos_1 == (*g_p0).pos))) goto LA10_;
						goto LA5;
					}
LA10_: ;
					(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)13);
					pos_1 += ((NI)1);
					switch (((NU8)((*g_p0).buf[pos_1]))) {
					case 120:
					{
						pos_1 += ((NI)1);
						{
							NI i_1;
							NI res_1;
							i_1 = (NI)0;
							res_1 = ((NI)1);
							{
								while (1) {
									if (!(res_1 <= ((NI)2))) goto LA15;
									i_1 = ((NI) (res_1));
									{
										if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(57)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(65)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(70)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(97)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(102)))) goto LA18_;
										pos_1 += ((NI)1);
									}
LA18_: ;
									res_1 += ((NI)1);
								} LA15: ;
							}
						}
						goto LA5;
					}
					break;
					case 117:
					{
						pos_1 += ((NI)1);
						{
							NI i_2;
							NI res_2;
							i_2 = (NI)0;
							res_2 = ((NI)1);
							{
								while (1) {
									if (!(res_2 <= ((NI)4))) goto LA23;
									i_2 = ((NI) (res_2));
									{
										if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(57)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(65)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(70)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(97)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(102)))) goto LA26_;
										pos_1 += ((NI)1);
									}
LA26_: ;
									res_2 += ((NI)1);
								} LA23: ;
							}
						}
						goto LA5;
					}
					break;
					case 85:
					{
						pos_1 += ((NI)1);
						{
							NI i_3;
							NI res_3;
							i_3 = (NI)0;
							res_3 = ((NI)1);
							{
								while (1) {
									if (!(res_3 <= ((NI)8))) goto LA31;
									i_3 = ((NI) (res_3));
									{
										if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(57)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(65)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(70)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(97)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(102)))) goto LA34_;
										pos_1 += ((NI)1);
									}
LA34_: ;
									res_3 += ((NI)1);
								} LA31: ;
							}
						}
						goto LA5;
					}
					break;
					default:
					{
						pos_1 += ((NI)1);
					}
					break;
					}
					goto LA5;
				}
				break;
				case 0:
				{
					(*g_p0).state = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)36);
					goto LA5;
				}
				break;
				case 34:
				{
					pos_1 += ((NI)1);
					(*g_p0).state = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)36);
					goto LA5;
				}
				break;
				default:
				{
					pos_1 += ((NI)1);
				}
				break;
				}
			}
		} LA5: ;
	}
	goto LA1_;
LA3_: ;
	{
		if (!((*g_p0).state == ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)12))) goto LA41_;
		(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)10);
		pos_1 += ((NI)1);
		{
			while (1) {
				switch (((NU8)((*g_p0).buf[pos_1]))) {
				case 39:
				{
					pos_1 += ((NI)1);
					{
						if (!((NU8)((*g_p0).buf[pos_1]) == (NU8)(39))) goto LA48_;
						pos_1 += ((NI)1);
						(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)13);
					}
					goto LA46_;
LA48_: ;
					{
						(*g_p0).state = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)36);
					}
LA46_: ;
					goto LA43;
				}
				break;
				default:
				{
					pos_1 += ((NI)1);
				}
				break;
				}
			}
		} LA43: ;
	}
	goto LA1_;
LA41_: ;
	{
		if (!((*g_p0).state == ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)27))) goto LA53_;
		switch (((NU8)((*g_p0).buf[pos_1]))) {
		case 32:
		case 9:
		{
			(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)2);
			{
				while (1) {
					if (!(((NU8)((*g_p0).buf[pos_1])) == ((NU8)(32)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(9)))) goto LA57;
					pos_1 += ((NI)1);
				} LA57: ;
			}
		}
		break;
		case 35:
		{
			(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)16);
			{
				while (1) {
					if (!!((((NU8)((*g_p0).buf[pos_1])) == ((NU8)(0)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(10)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(13))))) goto LA60;
					pos_1 += ((NI)1);
				} LA60: ;
			}
		}
		break;
		case 10:
		case 13:
		{
		}
		break;
		default:
		{
			(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)1);
			(*g_p0).state = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)36);
		}
		break;
		}
		{
			NIM_BOOL T65_;
			T65_ = (NIM_BOOL)0;
			T65_ = (((NU8)((*g_p0).buf[pos_1])) == ((NU8)(10)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(13)));
			if (!(T65_)) goto LA66_;
			T65_ = ((*g_p0).state == ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)27));
LA66_: ;
			if (!T65_) goto LA67_;
			(*g_p0).state = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)11);
		}
LA67_: ;
	}
	goto LA1_;
LA53_: ;
	{
		NI lookbehind_1;
		NI headerStart_1;
		NI indentation_1;
		NI parentIndentation_1;
		NI minIndentation_1;
		if (!((*g_p0).state == ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)11))) goto LA70_;
		(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)11);
		lookbehind_1 = (NI)(pos_1 - ((NI)1));
		headerStart_1 = ((NI)-1);
		{
			while (1) {
				NIM_BOOL T74_;
				T74_ = (NIM_BOOL)0;
				T74_ = (((NI)0) <= lookbehind_1);
				if (!(T74_)) goto LA75_;
				T74_ = !((((NU8)((*g_p0).buf[lookbehind_1])) == ((NU8)(10)) || ((NU8)((*g_p0).buf[lookbehind_1])) == ((NU8)(13))));
LA75_: ;
				if (!T74_) goto LA73;
				{
					NIM_BOOL T78_;
					T78_ = (NIM_BOOL)0;
					T78_ = (headerStart_1 == ((NI)-1));
					if (!(T78_)) goto LA79_;
					T78_ = (((NU8)((*g_p0).buf[lookbehind_1])) == ((NU8)(124)) || ((NU8)((*g_p0).buf[lookbehind_1])) == ((NU8)(62)));
LA79_: ;
					if (!T78_) goto LA80_;
					headerStart_1 = lookbehind_1;
				}
LA80_: ;
				lookbehind_1 -= ((NI)1);
			} LA73: ;
		}
		indentation_1 = ((NI)1);
		{
			while (1) {
				if (!((NU8)((*g_p0).buf[(NI)(lookbehind_1 + indentation_1)]) == (NU8)(32))) goto LA83;
				indentation_1 += ((NI)1);
			} LA83: ;
		}
		{
			if (!(((NU8)((*g_p0).buf[(NI)(lookbehind_1 + indentation_1)])) == ((NU8)(124)) || ((NU8)((*g_p0).buf[(NI)(lookbehind_1 + indentation_1)])) == ((NU8)(62)))) goto LA86_;
			{
				while (1) {
					NIM_BOOL T90_;
					T90_ = (NIM_BOOL)0;
					T90_ = (((NI)0) <= lookbehind_1);
					if (!(T90_)) goto LA91_;
					T90_ = (((NU8)((*g_p0).buf[lookbehind_1])) == ((NU8)(10)) || ((NU8)((*g_p0).buf[lookbehind_1])) == ((NU8)(13)));
LA91_: ;
					if (!T90_) goto LA89;
					lookbehind_1 -= ((NI)1);
					{
						while (1) {
							NIM_BOOL T94_;
							T94_ = (NIM_BOOL)0;
							T94_ = (((NI)0) <= lookbehind_1);
							if (!(T94_)) goto LA95_;
							T94_ = (((NU8)((*g_p0).buf[lookbehind_1])) == ((NU8)(32)) || ((NU8)((*g_p0).buf[lookbehind_1])) == ((NU8)(9)));
LA95_: ;
							if (!T94_) goto LA93;
							lookbehind_1 -= ((NI)1);
						} LA93: ;
					}
				} LA89: ;
			}
			{
				while (1) {
					NIM_BOOL T98_;
					T98_ = (NIM_BOOL)0;
					T98_ = (((NI)0) <= lookbehind_1);
					if (!(T98_)) goto LA99_;
					T98_ = !((((NU8)((*g_p0).buf[lookbehind_1])) == ((NU8)(10)) || ((NU8)((*g_p0).buf[lookbehind_1])) == ((NU8)(13))));
LA99_: ;
					if (!T98_) goto LA97;
					lookbehind_1 -= ((NI)1);
				} LA97: ;
			}
			indentation_1 = ((NI)1);
			{
				while (1) {
					if (!((NU8)((*g_p0).buf[(NI)(lookbehind_1 + indentation_1)]) == (NU8)(32))) goto LA101;
					indentation_1 += ((NI)1);
				} LA101: ;
			}
		}
LA86_: ;
		{
			if (!(lookbehind_1 == ((NI)-1))) goto LA104_;
			indentation_1 = ((NI)0);
		}
		goto LA102_;
LA104_: ;
		{
			NIM_BOOL T107_;
			NIM_BOOL T108_;
			NIM_BOOL T109_;
			T107_ = (NIM_BOOL)0;
			T108_ = (NIM_BOOL)0;
			T109_ = (NIM_BOOL)0;
			T109_ = ((NU8)((*g_p0).buf[(NI)(lookbehind_1 + ((NI)1))]) == (NU8)(45));
			if (!(T109_)) goto LA110_;
			T109_ = ((NU8)((*g_p0).buf[(NI)(lookbehind_1 + ((NI)2))]) == (NU8)(45));
LA110_: ;
			T108_ = T109_;
			if (!(T108_)) goto LA111_;
			T108_ = ((NU8)((*g_p0).buf[(NI)(lookbehind_1 + ((NI)3))]) == (NU8)(45));
LA111_: ;
			T107_ = T108_;
			if (!(T107_)) goto LA112_;
			T107_ = (((NU8)((*g_p0).buf[(NI)(lookbehind_1 + ((NI)4))])) >= ((NU8)(9)) && ((NU8)((*g_p0).buf[(NI)(lookbehind_1 + ((NI)4))])) <= ((NU8)(13)) || ((NU8)((*g_p0).buf[(NI)(lookbehind_1 + ((NI)4))])) == ((NU8)(32)));
LA112_: ;
			if (!T107_) goto LA113_;
			indentation_1 = ((NI)0);
		}
		goto LA102_;
LA113_: ;
LA102_: ;
		parentIndentation_1 = (NI)(indentation_1 - ((NI)1));
		{
			while (1) {
				if (!(((NU8)((*g_p0).buf[pos_1])) == ((NU8)(32)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(10)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(13)))) goto LA116;
				{
					if (!((NU8)((*g_p0).buf[pos_1]) == (NU8)(32))) goto LA119_;
					indentation_1 += ((NI)1);
				}
				goto LA117_;
LA119_: ;
				{
					indentation_1 = ((NI)0);
				}
LA117_: ;
				pos_1 += ((NI)1);
			} LA116: ;
		}
		minIndentation_1 = indentation_1;
		{
			while (1) {
				if (!(((NU8)((*g_p0).buf[headerStart_1])) == ((NU8)(62)) || ((NU8)((*g_p0).buf[headerStart_1])) == ((NU8)(124)) || ((NU8)((*g_p0).buf[headerStart_1])) == ((NU8)(43)) || ((NU8)((*g_p0).buf[headerStart_1])) == ((NU8)(45)))) goto LA123;
				headerStart_1 += ((NI)1);
			} LA123: ;
		}
		{
			if (!(((NU8)((*g_p0).buf[headerStart_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[headerStart_1])) <= ((NU8)(57)))) goto LA126_;
			minIndentation_1 = ((minIndentation_1 <= (NI)(((NU8)((*g_p0).buf[headerStart_1])) - ((NI)48))) ? minIndentation_1 : (NI)(((NU8)((*g_p0).buf[headerStart_1])) - ((NI)48)));
		}
LA126_: ;
		{
			while (1) {
				NIM_BOOL T130_;
				T130_ = (NIM_BOOL)0;
				T130_ = (parentIndentation_1 < indentation_1);
				if (!(T130_)) goto LA131_;
				T130_ = !(((NU8)((*g_p0).buf[pos_1]) == (NU8)(0)));
LA131_: ;
				if (!T130_) goto LA129;
				{
					NIM_BOOL T134_;
					NIM_BOOL T135_;
					NIM_BOOL T138_;
					NIM_BOOL T139_;
					NIM_BOOL T140_;
					NIM_BOOL T141_;
					T134_ = (NIM_BOOL)0;
					T135_ = (NIM_BOOL)0;
					T135_ = (indentation_1 < minIndentation_1);
					if (!(T135_)) goto LA136_;
					T135_ = ((NU8)((*g_p0).buf[pos_1]) == (NU8)(35));
LA136_: ;
					T134_ = T135_;
					if (T134_) goto LA137_;
					T138_ = (NIM_BOOL)0;
					T139_ = (NIM_BOOL)0;
					T140_ = (NIM_BOOL)0;
					T141_ = (NIM_BOOL)0;
					T141_ = (indentation_1 == ((NI)0));
					if (!(T141_)) goto LA142_;
					T141_ = ((NU8)((*g_p0).buf[pos_1]) == (NU8)(46));
LA142_: ;
					T140_ = T141_;
					if (!(T140_)) goto LA143_;
					T140_ = ((NU8)((*g_p0).buf[(NI)(pos_1 + ((NI)1))]) == (NU8)(46));
LA143_: ;
					T139_ = T140_;
					if (!(T139_)) goto LA144_;
					T139_ = ((NU8)((*g_p0).buf[(NI)(pos_1 + ((NI)2))]) == (NU8)(46));
LA144_: ;
					T138_ = T139_;
					if (!(T138_)) goto LA145_;
					T138_ = (((NU8)((*g_p0).buf[(NI)(pos_1 + ((NI)3))])) == ((NU8)(0)) || ((NU8)((*g_p0).buf[(NI)(pos_1 + ((NI)3))])) >= ((NU8)(9)) && ((NU8)((*g_p0).buf[(NI)(pos_1 + ((NI)3))])) <= ((NU8)(13)) || ((NU8)((*g_p0).buf[(NI)(pos_1 + ((NI)3))])) == ((NU8)(32)));
LA145_: ;
					T134_ = T138_;
LA137_: ;
					if (!T134_) goto LA146_;
					goto LA128;
				}
LA146_: ;
				minIndentation_1 = ((indentation_1 <= minIndentation_1) ? indentation_1 : minIndentation_1);
				{
					while (1) {
						if (!!((((NU8)((*g_p0).buf[pos_1])) == ((NU8)(0)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(10)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(13))))) goto LA149;
						pos_1 += ((NI)1);
					} LA149: ;
				}
				{
					while (1) {
						if (!(((NU8)((*g_p0).buf[pos_1])) == ((NU8)(32)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(10)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(13)))) goto LA151;
						{
							if (!((NU8)((*g_p0).buf[pos_1]) == (NU8)(32))) goto LA154_;
							indentation_1 += ((NI)1);
						}
						goto LA152_;
LA154_: ;
						{
							indentation_1 = ((NI)0);
						}
LA152_: ;
						pos_1 += ((NI)1);
					} LA151: ;
				}
			} LA129: ;
		} LA128: ;
		(*g_p0).state = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)36);
	}
	goto LA1_;
LA70_: ;
	{
		if (!((*g_p0).state == ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)36))) goto LA158_;
		switch (((NU8)((*g_p0).buf[pos_1]))) {
		case 32:
		case 9 ... 13:
		{
			(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)2);
			{
				while (1) {
					if (!(((NU8)((*g_p0).buf[pos_1])) == ((NU8)(32)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(9)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(13)))) goto LA162;
					pos_1 += ((NI)1);
				} LA162: ;
			}
		}
		break;
		case 35:
		{
			(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)16);
			pos_1 += ((NI)1);
			{
				while (1) {
					if (!!((((NU8)((*g_p0).buf[pos_1])) == ((NU8)(0)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(10)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(13))))) goto LA165;
					pos_1 += ((NI)1);
				} LA165: ;
			}
		}
		break;
		case 45:
		{
			pos_1 += ((NI)1);
			{
				if (!(((NU8)((*g_p0).buf[pos_1])) == ((NU8)(0)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(32)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(9)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(13)))) goto LA169_;
				(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)15);
			}
			goto LA167_;
LA169_: ;
			{
				NIM_BOOL T172_;
				NIM_BOOL T174_;
				T172_ = (NIM_BOOL)0;
				T172_ = ((NU8)((*g_p0).buf[pos_1]) == (NU8)(45));
				if (!(T172_)) goto LA173_;
				T174_ = (NIM_BOOL)0;
				T174_ = (pos_1 == ((NI)1));
				if (T174_) goto LA175_;
				T174_ = (((NU8)((*g_p0).buf[(NI)(pos_1 - ((NI)2))])) == ((NU8)(10)) || ((NU8)((*g_p0).buf[(NI)(pos_1 - ((NI)2))])) == ((NU8)(13)));
LA175_: ;
				T172_ = T174_;
LA173_: ;
				if (!T172_) goto LA176_;
				pos_1 += ((NI)1);
				{
					NIM_BOOL T180_;
					T180_ = (NIM_BOOL)0;
					T180_ = ((NU8)((*g_p0).buf[pos_1]) == (NU8)(45));
					if (!(T180_)) goto LA181_;
					T180_ = (((NU8)((*g_p0).buf[(NI)(pos_1 + ((NI)1))])) == ((NU8)(0)) || ((NU8)((*g_p0).buf[(NI)(pos_1 + ((NI)1))])) >= ((NU8)(9)) && ((NU8)((*g_p0).buf[(NI)(pos_1 + ((NI)1))])) <= ((NU8)(13)) || ((NU8)((*g_p0).buf[(NI)(pos_1 + ((NI)1))])) == ((NU8)(32)));
LA181_: ;
					if (!T180_) goto LA182_;
					pos_1 += ((NI)1);
					(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)9);
				}
				goto LA178_;
LA182_: ;
				{
					yamlPossibleNumber__packagesZdocutilsZhighlite_u1363(g_p0, (&pos_1));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA178_: ;
			}
			goto LA167_;
LA176_: ;
			{
				yamlPossibleNumber__packagesZdocutilsZhighlite_u1363(g_p0, (&pos_1));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA167_: ;
		}
		break;
		case 46:
		{
			{
				NIM_BOOL T189_;
				T189_ = (NIM_BOOL)0;
				T189_ = (pos_1 == ((NI)0));
				if (T189_) goto LA190_;
				T189_ = (((NU8)((*g_p0).buf[(NI)(pos_1 - ((NI)1))])) == ((NU8)(10)) || ((NU8)((*g_p0).buf[(NI)(pos_1 - ((NI)1))])) == ((NU8)(13)));
LA190_: ;
				if (!T189_) goto LA191_;
				pos_1 += ((NI)1);
				{
					NI i_4;
					NI res_4;
					i_4 = (NI)0;
					res_4 = ((NI)1);
					{
						while (1) {
							if (!(res_4 <= ((NI)2))) goto LA195;
							i_4 = ((NI) (res_4));
							{
								if (!!(((NU8)((*g_p0).buf[pos_1]) == (NU8)(46)))) goto LA198_;
								goto LA193;
							}
LA198_: ;
							pos_1 += ((NI)1);
							res_4 += ((NI)1);
						} LA195: ;
					}
				} LA193: ;
				{
					if (!(pos_1 == (NI)((*g_p0).start + ((NI)3)))) goto LA202_;
					(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)9);
					(*g_p0).state = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)1);
				}
				goto LA200_;
LA202_: ;
				{
					yamlPlainStrLit__packagesZdocutilsZhighlite_u1347(g_p0, (&pos_1));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA200_: ;
			}
			goto LA187_;
LA191_: ;
			{
				yamlPlainStrLit__packagesZdocutilsZhighlite_u1347(g_p0, (&pos_1));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA187_: ;
		}
		break;
		case 63:
		{
			pos_1 += ((NI)1);
			{
				if (!(((NU8)((*g_p0).buf[pos_1])) == ((NU8)(0)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(32)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(9)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(13)))) goto LA209_;
				(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)15);
			}
			goto LA207_;
LA209_: ;
			{
				yamlPlainStrLit__packagesZdocutilsZhighlite_u1347(g_p0, (&pos_1));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA207_: ;
		}
		break;
		case 58:
		{
			pos_1 += ((NI)1);
			{
				NIM_BOOL T215_;
				NIM_BOOL T217_;
				T215_ = (NIM_BOOL)0;
				T215_ = (((NU8)((*g_p0).buf[pos_1])) == ((NU8)(0)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(9)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(13)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(32)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(39)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(34)));
				if (T215_) goto LA216_;
				T217_ = (NIM_BOOL)0;
				T217_ = (((NI)0) < pos_1);
				if (!(T217_)) goto LA218_;
				T217_ = (((NU8)((*g_p0).buf[(NI)(pos_1 - ((NI)2))])) == ((NU8)(125)) || ((NU8)((*g_p0).buf[(NI)(pos_1 - ((NI)2))])) == ((NU8)(93)) || ((NU8)((*g_p0).buf[(NI)(pos_1 - ((NI)2))])) == ((NU8)(34)) || ((NU8)((*g_p0).buf[(NI)(pos_1 - ((NI)2))])) == ((NU8)(39)));
LA218_: ;
				T215_ = T217_;
LA216_: ;
				if (!T215_) goto LA219_;
				(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)15);
			}
			goto LA213_;
LA219_: ;
			{
				yamlPlainStrLit__packagesZdocutilsZhighlite_u1347(g_p0, (&pos_1));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA213_: ;
		}
		break;
		case 91:
		case 93:
		case 123:
		case 125:
		case 44:
		{
			pos_1 += ((NI)1);
			(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)15);
		}
		break;
		case 34:
		{
			pos_1 += ((NI)1);
			(*g_p0).state = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)10);
			(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)10);
		}
		break;
		case 39:
		{
			(*g_p0).state = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)12);
			(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)1);
		}
		break;
		case 33:
		{
			(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)19);
			pos_1 += ((NI)1);
			{
				if (!((NU8)((*g_p0).buf[pos_1]) == (NU8)(60))) goto LA228_;
				{
					while (1) {
						if (!!((((NU8)((*g_p0).buf[pos_1])) == ((NU8)(0)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(62)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(9)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(13)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(32))))) goto LA231;
						pos_1 += ((NI)1);
					} LA231: ;
				}
				{
					if (!((NU8)((*g_p0).buf[pos_1]) == (NU8)(62))) goto LA234_;
					pos_1 += ((NI)1);
				}
LA234_: ;
			}
			goto LA226_;
LA228_: ;
			{
				{
					while (1) {
						if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(65)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(90)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(97)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(122)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(57)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(45)))) goto LA238;
						pos_1 += ((NI)1);
					} LA238: ;
				}
				switch (((NU8)((*g_p0).buf[pos_1]))) {
				case 33:
				{
					pos_1 += ((NI)1);
					{
						while (1) {
							if (!!((((NU8)((*g_p0).buf[pos_1])) == ((NU8)(0)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(9)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(13)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(32)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(44)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(91)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(93)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(123)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(125))))) goto LA241;
							pos_1 += ((NI)1);
						} LA241: ;
					}
				}
				break;
				case 0:
				case 9 ... 13:
				case 32:
				{
				}
				break;
				default:
				{
					{
						while (1) {
							if (!!((((NU8)((*g_p0).buf[pos_1])) == ((NU8)(0)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(9)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(13)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(32))))) goto LA245;
							pos_1 += ((NI)1);
						} LA245: ;
					}
				}
				break;
				}
			}
LA226_: ;
		}
		break;
		case 38:
		{
			(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)30);
			{
				while (1) {
					if (!!((((NU8)((*g_p0).buf[pos_1])) == ((NU8)(0)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(9)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(13)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(32))))) goto LA248;
					pos_1 += ((NI)1);
				} LA248: ;
			}
		}
		break;
		case 42:
		{
			(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)31);
			{
				while (1) {
					if (!!((((NU8)((*g_p0).buf[pos_1])) == ((NU8)(0)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(9)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(13)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(32))))) goto LA251;
					pos_1 += ((NI)1);
				} LA251: ;
			}
		}
		break;
		case 124:
		case 62:
		{
			(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)27);
			(*g_p0).state = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)27);
			pos_1 += ((NI)1);
			{
				while (1) {
					if (!(((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(48)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(57)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(43)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(45)))) goto LA254;
					pos_1 += ((NI)1);
				} LA254: ;
			}
		}
		break;
		case 48 ... 57:
		{
			yamlPossibleNumber__packagesZdocutilsZhighlite_u1363(g_p0, (&pos_1));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		case 0:
		{
			(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)0);
		}
		break;
		default:
		{
			yamlPlainStrLit__packagesZdocutilsZhighlite_u1347(g_p0, (&pos_1));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		}
	}
	goto LA1_;
LA158_: ;
	{
		switch (((NU8)((*g_p0).buf[pos_1]))) {
		case 37:
		{
			{
				NIM_BOOL T262_;
				T262_ = (NIM_BOOL)0;
				T262_ = (pos_1 == ((NI)0));
				if (T262_) goto LA263_;
				T262_ = (((NU8)((*g_p0).buf[(NI)(pos_1 - ((NI)1))])) == ((NU8)(10)) || ((NU8)((*g_p0).buf[(NI)(pos_1 - ((NI)1))])) == ((NU8)(13)));
LA263_: ;
				if (!T262_) goto LA264_;
				(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)26);
				{
					while (1) {
						if (!!((((NU8)((*g_p0).buf[pos_1])) == ((NU8)(0)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(10)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(13))))) goto LA267;
						pos_1 += ((NI)1);
					} LA267: ;
				}
			}
			goto LA260_;
LA264_: ;
			{
				(*g_p0).state = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)36);
				yamlPlainStrLit__packagesZdocutilsZhighlite_u1347(g_p0, (&pos_1));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA260_: ;
		}
		break;
		case 32:
		case 9 ... 13:
		{
			(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)2);
			{
				while (1) {
					if (!(((NU8)((*g_p0).buf[pos_1])) == ((NU8)(32)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(9)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(13)))) goto LA271;
					pos_1 += ((NI)1);
				} LA271: ;
			}
		}
		break;
		case 35:
		{
			(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)16);
			{
				while (1) {
					if (!!((((NU8)((*g_p0).buf[pos_1])) == ((NU8)(0)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(10)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(13))))) goto LA274;
					pos_1 += ((NI)1);
				} LA274: ;
			}
		}
		break;
		case 0:
		{
			(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)0);
		}
		break;
		default:
		{
			(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)1);
			(*g_p0).state = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)36);
		}
		break;
		}
	}
LA1_: ;
	(*g_p0).length = (NI)(pos_1 - (*g_p0).pos);
	(*g_p0).pos = pos_1;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, pythonNextToken__packagesZdocutilsZhighlite_u1980)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimNextToken__packagesZdocutilsZhighlite_u404(g_p0, keywords__packagesZdocutilsZhighlite_u1982, 35);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, cmdNextToken__packagesZdocutilsZhighlite_u2020)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0, NIM_BOOL dollarPrompt_p1) {
	NI pos_1;
	pos_1 = (*g_p0).pos;
	(*g_p0).start = (*g_p0).pos;
	{
		tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA T5_;
		if (!((*g_p0).state == ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)0))) goto LA3_;
		T5_ = (tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)0;
		{
			if (!dollarPrompt_p1) goto LA8_;
			(*g_p0).state = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)32);
		}
		goto LA6_;
LA8_: ;
		{
			(*g_p0).state = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)34);
		}
LA6_: ;
	}
LA3_: ;
	switch (((NU8)((*g_p0).buf[pos_1]))) {
	case 32:
	case 9 ... 13:
	{
		(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)2);
		{
			while (1) {
				if (!(((NU8)((*g_p0).buf[pos_1])) == ((NU8)(32)) || ((NU8)((*g_p0).buf[pos_1])) >= ((NU8)(9)) && ((NU8)((*g_p0).buf[pos_1])) <= ((NU8)(13)))) goto LA13;
				{
					tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA T18_;
					if (!((NU8)((*g_p0).buf[pos_1]) == (NU8)(10))) goto LA16_;
					T18_ = (tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)0;
					{
						if (!dollarPrompt_p1) goto LA21_;
						(*g_p0).state = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)32);
					}
					goto LA19_;
LA21_: ;
					{
						(*g_p0).state = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)34);
					}
LA19_: ;
				}
LA16_: ;
				pos_1 += ((NI)1);
			} LA13: ;
		}
	}
	break;
	case 39:
	case 34:
	{
		NIM_CHAR q_1;
		(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)35);
		q_1 = (*g_p0).buf[pos_1];
		pos_1 += ((NI)1);
		{
			while (1) {
				if (!!((((NU8)((*g_p0).buf[pos_1])) == ((NU8)(q_1)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(0))))) goto LA26;
				pos_1 += ((NI)1);
			} LA26: ;
		}
		{
			if (!((NU8)((*g_p0).buf[pos_1]) == (NU8)(q_1))) goto LA29_;
			pos_1 += ((NI)1);
		}
LA29_: ;
	}
	break;
	case 35:
	{
		(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)16);
		{
			while (1) {
				if (!!((((NU8)((*g_p0).buf[pos_1])) == ((NU8)(10)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(0))))) goto LA33;
				pos_1 += ((NI)1);
			} LA33: ;
		}
	}
	break;
	case 38:
	case 124:
	{
		(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)14);
		pos_1 += ((NI)1);
		{
			if (!((NU8)((*g_p0).buf[pos_1]) == (NU8)((*g_p0).buf[(NI)(pos_1 - ((NI)1))]))) goto LA37_;
			pos_1 += ((NI)1);
		}
LA37_: ;
		(*g_p0).state = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)34);
	}
	break;
	case 40:
	{
		(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)14);
		(*g_p0).state = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)34);
		pos_1 += ((NI)1);
	}
	break;
	case 41:
	{
		(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)14);
		pos_1 += ((NI)1);
	}
	break;
	case 59:
	{
		(*g_p0).state = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)34);
		(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)14);
		pos_1 += ((NI)1);
	}
	break;
	case 0:
	{
		(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)0);
	}
	break;
	default:
	{
		{
			NIM_BOOL T46_;
			T46_ = (NIM_BOOL)0;
			T46_ = dollarPrompt_p1;
			if (!(T46_)) goto LA47_;
			T46_ = ((*g_p0).state == ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)32));
LA47_: ;
			if (!T46_) goto LA48_;
			{
				NIM_BOOL T52_;
				T52_ = (NIM_BOOL)0;
				T52_ = ((NU8)((*g_p0).buf[pos_1]) == (NU8)(36));
				if (!(T52_)) goto LA53_;
				T52_ = (((NU8)((*g_p0).buf[(NI)(pos_1 + ((NI)1))])) == ((NU8)(32)) || ((NU8)((*g_p0).buf[(NI)(pos_1 + ((NI)1))])) == ((NU8)(9)));
LA53_: ;
				if (!T52_) goto LA54_;
				(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)32);
				pos_1 += ((NI)2);
				(*g_p0).state = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)34);
			}
			goto LA50_;
LA54_: ;
			{
				(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)33);
				{
					while (1) {
						if (!!((((NU8)((*g_p0).buf[pos_1])) == ((NU8)(10)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(0))))) goto LA58;
						pos_1 += ((NI)1);
					} LA58: ;
				}
			}
LA50_: ;
		}
		goto LA44_;
LA48_: ;
		{
			{
				if (!((*g_p0).state == ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)34))) goto LA62_;
				(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)34);
				(*g_p0).state = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)35);
			}
			goto LA60_;
LA62_: ;
			{
				(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)35);
			}
LA60_: ;
			{
				while (1) {
					if (!!(((TM__0kVEnxqJYMmsZjjZ9a1FeBw_178[(NU)((((NU8)((*g_p0).buf[pos_1]))))>>3] &(1U<<((NU)((((NU8)((*g_p0).buf[pos_1]))))&7U)))!=0))) goto LA66;
					{
						NIM_BOOL T69_;
						T69_ = (NIM_BOOL)0;
						T69_ = ((NU8)((*g_p0).buf[pos_1]) == (NU8)(59));
						if (!(T69_)) goto LA70_;
						T69_ = ((NU8)((*g_p0).buf[(NI)(pos_1 + ((NI)1))]) == (NU8)(32));
LA70_: ;
						if (!T69_) goto LA71_;
						goto LA65;
					}
LA71_: ;
					{
						NIM_BOOL T75_;
						T75_ = (NIM_BOOL)0;
						T75_ = ((*g_p0).kind == ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)35));
						if (!(T75_)) goto LA76_;
						T75_ = (((NU8)((*g_p0).buf[pos_1])) == ((NU8)(47)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(92)) || ((NU8)((*g_p0).buf[pos_1])) == ((NU8)(46)));
LA76_: ;
						if (!T75_) goto LA77_;
						(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)8);
					}
					goto LA73_;
LA77_: ;
					{
						NIM_BOOL T80_;
						T80_ = (NIM_BOOL)0;
						T80_ = ((*g_p0).kind == ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)34));
						if (!(T80_)) goto LA81_;
						T80_ = ((NU8)((*g_p0).buf[pos_1]) == (NU8)(61));
LA81_: ;
						if (!T80_) goto LA82_;
						(*g_p0).kind = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)8);
						(*g_p0).state = ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)34);
					}
					goto LA73_;
LA82_: ;
LA73_: ;
					pos_1 += ((NI)1);
				} LA66: ;
			} LA65: ;
		}
LA44_: ;
	}
	break;
	}
	(*g_p0).length = (NI)(pos_1 - (*g_p0).pos);
	(*g_p0).pos = pos_1;
}
N_LIB_PRIVATE N_NIMCALL(void, getNextToken__packagesZdocutilsZhighlite_u2142)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0, tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA lang_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*g_p0).lang = lang_p1;
	switch (lang_p1) {
	case ((tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA)0):
	{
	}
	break;
	case ((tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA)1):
	{
		tySequence__sM4lkSb7zS6F7OVMvW9cffQ T3_;
		T3_.len = 0; T3_.p = NIM_NIL;
		T3_.len = 0; T3_.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(0, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
		nimNextToken__packagesZdocutilsZhighlite_u404(g_p0, ((T3_).p) ? (T3_.p->data) : NIM_NIL, T3_.len);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA)2):
	{
		cppNextToken__packagesZdocutilsZhighlite_u1227(g_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA)3):
	{
		csharpNextToken__packagesZdocutilsZhighlite_u1267(g_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA)4):
	{
		cNextToken__packagesZdocutilsZhighlite_u1187(g_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA)5):
	{
		javaNextToken__packagesZdocutilsZhighlite_u1307(g_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA)6):
	{
		yamlNextToken__packagesZdocutilsZhighlite_u1485(g_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA)7):
	{
		pythonNextToken__packagesZdocutilsZhighlite_u1980(g_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA)8):
	{
		cmdNextToken__packagesZdocutilsZhighlite_u2020(g_p0, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA)9):
	{
		cmdNextToken__packagesZdocutilsZhighlite_u2020(g_p0, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default: __builtin_unreachable();
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, deinitGeneralTokenizer__packagesZdocutilsZhighlite_u157)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0) {
}
